@@ -126,6 +126,9 @@ class BaseWidgetContainer
 		$now = date("Y/m/d H:i:s");
 		$this->tmpl->addVar("_widget", "_DATE", "created $now");
 		
+		// 共通スクリプトディレクトリを設定
+		$this->tmpl->addVar("_widget", "_SCRIPTS_URL", $gEnvManager->getScriptsUrl());
+		
 		// デバッグ出力があるときは表示
 		if ($gEnvManager->getSystemDebugOut() && method_exists($this,'_debugString')){
 			$debugStr = $this->_debugString();
