@@ -1631,7 +1631,7 @@ class SystemDb extends BaseDb
 		return $this->endTransaction();
 	}
 	/**
-	 * 初期導入パラメータを取得
+	 * 汎用連想配列型パラメータを取得
 	 *
 	 * @param string	$key			キー
 	 * @param string	$name			名前
@@ -1651,14 +1651,33 @@ class SystemDb extends BaseDb
 		return $retValue;
 	}
 	/**
-	 * 初期導入パラメータを更新
+	 * 汎用連想配列型パラメータのキーをシリアル番号で取得
+	 *
+	 * @param int		$serial			シリアル番号
+	 * @return string					キー文字列、未設定の場合は空文字列
+	 */
+	function getKeyBySerial($serial)
+	{
+		$retValue = '';
+		$queryStr  = 'SELECT * FROM _key_value ';
+		$queryStr .=   'WHERE kv_deleted = false ';	// 削除されていない
+		$queryStr .=   'AND kv_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		if ($ret){
+			$retValue = $row['kv_id'];
+		}
+		return $retValue;
+	}
+	/**
+	 * 汎用連想配列型パラメータを更新
 	 *
 	 * @param string $key		キーとなる項目値
 	 * @param string $value		値
 	 * @param string $name		名前
+	 * @param string $group		グループID
 	 * @return					true = 正常、false=異常
 	 */
-	function updateKeyValue($key, $value, $name='')
+	function updateKeyValue($key, $value, $name='', $group = '')
 	{
 		global $gEnvManager;
 		
@@ -1699,10 +1718,10 @@ class SystemDb extends BaseDb
 		
 		// データを追加
 		$queryStr = 'INSERT INTO _key_value ';
-		$queryStr .=  '(kv_id, kv_history_index, kv_value, kv_name, kv_description, kv_create_user_id, kv_create_dt) ';
+		$queryStr .=  '(kv_id, kv_history_index, kv_value, kv_name, kv_description, kv_group_id, kv_create_user_id, kv_create_dt) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($key, $historyIndex, $value, $name, $desc, $userId, $now));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?)';
+		$this->execStatement($queryStr, array($key, $historyIndex, $value, $name, $desc, $group, $userId, $now));
 			
 		// トランザクション確定
 		$ret = $this->endTransaction();
