@@ -40,8 +40,8 @@ define('M3_SYSTEM_DEBUG_OUT', true);// デバッグ文出力を行うかどう
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'1.2.0');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2008/1/23');		// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'1.2.2');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2008/2/1');		// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms & web communication framework.');		// システムの説明
 
@@ -116,10 +116,12 @@ define('M3_REQUEST_PARAM_WIDGET_ID',				'widget');			// ウィジェットID
 define('M3_REQUEST_PARAM_URL',						'url');				// リンク先等のURL
 define('M3_REQUEST_PARAM_STAMP',					'stamp');			// 公開発行ID
 //define('M3_REQUEST_PARAM_CONTAINER',				'cont');			// コンテナ
+define('M3_REQUEST_PARAM_OPTION',					'opt');				// 通信オプション
 define('M3_REQUEST_PARAM_OPERATION_COMMAND',		'cmd');				// 実行処理
 define('M3_REQUEST_PARAM_OPERATION_TASK',			'task');			// ウィジェット間共通処理
+define('M3_REQUEST_PARAM_OPERATION_ACT',			'act');				// クライアントからの実行処理
 define('M3_REQUEST_PARAM_OPERATION_LANG',			'lang');			// 言語指定表示
-define('M3_REQUEST_PARAM_OPERATION_TODO',      		'todo');			// ウィジェットに実行させる処理
+define('M3_REQUEST_PARAM_OPERATION_TODO',      		'todo');			// 指定ウィジェットに実行させる処理
 define('M3_REQUEST_PARAM_FROM',						'from');			// メッセージの送信元ウィジェットID
 define('M3_REQUEST_PARAM_VIEW_STYLE',				'style');			// 表示スタイル
 define('M3_REQUEST_PARAM_FORWARD',					'forward');			// 画面遷移用パラメータ
