@@ -11,7 +11,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -69,7 +69,6 @@ class LaunchManager
 		$mainContainer = new $class();
 		$mainContainer->process($gRequestManager);
 	}
-	
 	/**
 	 * ウィジェットプログラムを実行
 	 *
@@ -209,5 +208,49 @@ class LaunchManager
 			$widgetContainer->process($gRequestManager, $install);
 		}
 	}
+	/**
+	 * 携帯用プログラムを実行
+	 *
+	 * @param string $filepath		呼び出し元ファイルのフルパス。通常は「__FILE__」。OSによってパスの表現が違うので注意。
+	 */
+	function goMobile($filepath = '')
+	{
+		global $gEnvManager;
+		global $gRequestManager;
+
+		// ルートから$filepathへの相対パスで「FrameContainer.php」の先頭につける
+		// サフィックスを作成する
+		// 例) 相対パスが「admin/index.php」のとき「admin_index」
+		if ($filepath == ''){
+			$basename = basename($_SERVER["PHP_SELF"], '.php');
+		} else {
+			// ルートまでのパスを削除
+			$path = str_replace(M3_SYSTEM_ROOT_PATH, '', $filepath);
+			$path = str_replace(DIRECTORY_SEPARATOR, '/', $path);
+			$path = trim($path, '/');
+			$pathArray = split('/', $path);
+			$basename = '';
+			for ($i = 0; $i < count($pathArray); $i++){
+				if ($i == 0){
+					$basename .= $pathArray[$i];
+				} else {
+					//$basename .= ucfirst($pathArray[$i]);
+					$basename .= ('_' . $pathArray[$i]);
+				}
+			}
+			$basename = basename($basename, '.php');
+		}
+		
+		// ページIDを設定
+		$gEnvManager->setCurrentPageId($basename);
+
+		// ファイル名から、コンテナクラスファイル取り込み
+		require_once($gEnvManager->getContainerPath() . '/' . $basename . 'FrameContainer.php');
+		
+		// コンテナクラスを起動
+		$class = $basename . 'FrameContainer';
+		$mainContainer = new $class();
+		$mainContainer->process($gRequestManager);
+	}
 }
 ?>
