@@ -33,6 +33,9 @@ class PageManager
 	private $latelaunchWidgetParam;		// 遅延実行ウィジェットのパラメータ
 	private $viewPositions = array();	// テンプレート上のポジション
 	private $updateParentWindow;		// 親ウィンドウを再描画するかどうか
+	private $useMootools;				// MootoolsをPrototypeの代わりに使用するかどうか
+	private $useScriptaculous;			// scriptaculousを使用するかどうか
+	const ADMIN_WIDGET_ID = 'admin_main';		// 管理用ウィジェットのウィジェットID
 	const WIDGET_ID_TAG_START = '{{WIDGETID:';		// 遅延実行用タグ
 	const WIDGET_ID_TAG_END = '}}';		// 遅延実行用タグ
 	const WIDGET_ID_SEPARATOR = ',';
@@ -46,6 +49,11 @@ class PageManager
 	const IWIDTET_CMD_INIT = 'init';			// 初期化
 	const IWIDTET_CMD_UPDATE = 'update';		// 更新
 	const IWIDTET_CMD_CALC = 'calc';			// 計算
+	const DEFAULT_TEMPLATE_CSS_FILE = '/css/template_css.css';		// デフォルトのテンプレートCSSファイル
+	// ファイル名
+	const PROTOTYPE_FILENAME = 'prototype.js';						// Prototype
+	const MOOTOOLS_FILENAME = 'mootools-release-1.11.js';			// mootools
+	const SCRIPTACULOUS_FILENAME = 'scriptaculous/scriptaculous.js';			// scriptaculous
 	
 	/**
 	 * コンストラクタ
@@ -61,10 +69,12 @@ class PageManager
 		// 共通スクリプトファイル
 		// 「ルート/scripts」ディレクトリからの相対パスで指定する
 		$this->_defaultScriptFiles = array('m3std.js');
-		$this->_defaultAdminScriptFiles = array('prototype.js',
+		$this->_defaultAdminScriptFiles = array(self::PROTOTYPE_FILENAME,
 											'm3std.js',
+											'm3admin.js',
 											'm3ajax.js',
 											'fckeditor/fckeditor.js',		// FCKEditor
+								//			'mootools-release-1.11.js',			// mootools
 											'bubble-tooltip/js/bubble-tooltip.js');// Bubble Tooltip
 											
 		// 遅延ウィジェットリスト									
@@ -138,6 +148,24 @@ class PageManager
 	{
 		$this->hasScriptCache = $status;
 	}
+	/**
+	 * MootoolsをPrototypeの代わりに使用するかどうか
+	 *
+	 * @return 				なし
+	 */
+	function useMootools()
+	{
+		$this->useMootools = true;
+	}
+	/**
+	 * scriptaculousを使用するかどうか
+	 *
+	 * @return 				なし
+	 */
+	function useScriptaculous()
+	{
+		$this->useScriptaculous = true;
+	}
 	/**
 	 * 親ウィンドウを再描画
 	 *
@@ -337,7 +365,8 @@ class PageManager
 				}
 			}
 		}
-		echo $destBuf;
+		//echo $destBuf;
+		return $destBuf;
 	}
 	/**
 	 * ウィジェット検索モードの場合のページサブIDの設定
@@ -557,12 +586,26 @@ class PageManager
 			// HTMLのヘッダ部(headタグ内)出力
 			$this->getHeader();
 			
-			echo '<link href="' . $gEnvManager->getTemplatesUrl() . '/_admin/css/style.css" rel="stylesheet" type="text/css"/>' . M3_NL;
-			echo '<!--[if IE]><link rel="stylesheet" type="text/css" media="screen" href="' . $gEnvManager->getTemplatesUrl() . '/_admin/css/iestyles.css"  /><![endif]-->' . M3_NL;
-			
 			// ウィジェットのJavascriptを読み込む
 			$widgetId = $gEnvManager->getCurrentWidgetId();		// カレントのウィジェットID
 			
+			// テンプレートの設定
+			if ($cmd == M3_REQUEST_CMD_CONFIG_WIDGET){	// ウィジェット詳細設定画面のとき
+				// 管理用テンプレート
+				echo '<link href="' . $gEnvManager->getTemplatesUrl() . '/_admin/css/style.css" rel="stylesheet" type="text/css"/>' . M3_NL;
+				echo '<!--[if IE]><link rel="stylesheet" type="text/css" media="screen" href="' . $gEnvManager->getTemplatesUrl() . '/_admin/css/iestyles.css"  /><![endif]-->' . M3_NL;
+			} else if ($cmd == M3_REQUEST_CMD_SHOW_WIDGET){		// ウィジェットの単体表示のとき
+				// ウィジェットが管理用ウィジェットかどうかチェック
+				if ($widgetId == self::ADMIN_WIDGET_ID){			// 管理用ウィジェットの場合
+					// 管理用テンプレート
+					echo '<link href="' . $gEnvManager->getTemplatesUrl() . '/_admin/css/style.css" rel="stylesheet" type="text/css"/>' . M3_NL;
+					echo '<!--[if IE]><link rel="stylesheet" type="text/css" media="screen" href="' . $gEnvManager->getTemplatesUrl() . '/_admin/css/iestyles.css"  /><![endif]-->' . M3_NL;
+				} else {
+					$curTemplate = $this->db->getDefaultTemplateId();
+					$templateFile = $gEnvManager->getTemplatesUrl() . '/' . $curTemplate . self::DEFAULT_TEMPLATE_CSS_FILE;
+					echo '<link href="' . $templateFile . '" rel="stylesheet" type="text/css"/>' . M3_NL;
+				}
+			}
 			// ウィジェット情報取得
 			$ret = $this->db->getWidgetInfo($widgetId, $row);
 						
@@ -591,19 +634,17 @@ class PageManager
 			echo '<title>' . $title . '</title>' . M3_NL;
 			echo '</head>' . M3_NL;
 			echo '<body>' . M3_NL;
-			//if (!empty($title)){
-			if ($cmd == M3_REQUEST_CMD_CONFIG_WIDGET){	// ウィジェット詳細設定画面のとき
+			if ($cmd == M3_REQUEST_CMD_SHOW_WIDGET ||		// ウィジェットの単体表示のとき
+				$cmd == M3_REQUEST_CMD_CONFIG_WIDGET){	// ウィジェット詳細設定画面のとき
 				// 別ウィンドウで表示のときは、「閉じる」ボタンを表示
 				$openBy = $gRequestManager->trimValueOf(M3_REQUEST_PARAM_OPEN_BY);		// ウィンドウオープンタイプ
 				if ($openBy == 'other'){
 					echo '<br>' . M3_NL;
 					echo '<div align="right"><input type="button" class="button" value="閉じる" onClick="window.close();">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</div>' . M3_NL;
 				}
-				//echo '<h3>' . $title . 'の詳細設定</h3>' . M3_NL;
 			}
-			//}
 		//	echo '<br>' . M3_NL;
-			echo '<div align="center">' . M3_NL;
+//			echo '<div align="center">' . M3_NL;
 			echo '<!-- Widget Start -->' . M3_NL;
 		}
 	}
@@ -617,7 +658,7 @@ class PageManager
 		// ウィジェット単体表示のときのみ出力
 		if ($this->showWidget){
 			echo '<!-- Widget End -->' . M3_NL;
-			echo '</div>' . M3_NL;
+//			echo '</div>' . M3_NL;
 			if ($cmd == M3_REQUEST_CMD_CONFIG_WIDGET){	// ウィジェット詳細設定画面のとき
 				if ($this->updateParentWindow){			// 親ウィンドウ再描画のとき
 					echo '<SCRIPT language="JavaScript">' . M3_NL;
@@ -696,18 +737,31 @@ class PageManager
 			// 管理画面用の共通スクリプトを読み込む
 			$count = count($this->_defaultAdminScriptFiles);
 			for ($i = 0; $i < $count; $i++){
-				$scriptURL = $gEnvManager->getScriptsUrl() . '/' . $this->_defaultAdminScriptFiles[$i];
+				$scriptFilename = $this->_defaultAdminScriptFiles[$i];
+			
+				// PrototypeをMootoolsに変更のとき
+				if ($this->useMootools && $scriptFilename == self::PROTOTYPE_FILENAME) $scriptFilename = self::MOOTOOLS_FILENAME;
+				$scriptURL = $gEnvManager->getScriptsUrl() . '/' . $scriptFilename;
 			
 				// スクリプトをキャッシュ保存しない場合は、パラメータを付加
 				if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();
 				echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
 			}
+			// Scriptaculousファイルの追加
+			if ($this->useScriptaculous){
+				$scriptURL = $gEnvManager->getScriptsUrl() . '/' . self::SCRIPTACULOUS_FILENAME;
+								
+				// スクリプトをキャッシュ保存しない場合は、パラメータを付加
+				if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();
+				echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
+			}
+			/*
 			if ($cmd == M3_REQUEST_CMD_CONFIG_WIDGET){	// ウィジェット詳細設定画面のとき
 				// 管理機能用スクリプト
 				$scriptURL = $gEnvManager->getScriptsUrl() . '/m3admin.js';
 				if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();// スクリプトをキャッシュ保存しない場合は、パラメータを付加
 				echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
-			}
+			}*/
 		} else {			// 通常画面
 			$count = count($this->_defaultScriptFiles);
 			for ($i = 0; $i < $count; $i++){
@@ -730,7 +784,7 @@ class PageManager
 				echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
 		
 				// scriptaculous
-				$scriptURL = $gEnvManager->getScriptsUrl() . '/scriptaculous/scriptaculous.js';
+				$scriptURL = $gEnvManager->getScriptsUrl() . '/' . self::SCRIPTACULOUS_FILENAME;
 				if (!$this->hasScriptCache) $scriptURL .= $this->getCacheParam();// スクリプトをキャッシュ保存しない場合は、パラメータを付加
 				echo '<script language="JavaScript" src="' . $scriptURL . '" type="text/javascript"></script>' . M3_NL;
 		
@@ -929,10 +983,10 @@ class PageManager
 						$hasAdmin = '1';
 					}
 					if (empty($this->pageDefRows[$i]['pd_sub_id'])){		// 共通ウィジェットのときは色を変える
-						$menuItem1 = '共通項目を解除';
+						$menuItem1 = 'ページ共通を解除';
 						echo '<div id="' . $widgetTag . '" class="' . self::WIDTET_CLASS_NAME . '" ondblclick="m3DoubleClickWidget(event, this, \'' . $widgetId . '\');" style="background-color:#ffe4c4;margin:2px;padding:10px;border:2px solid green;color:#800000;" context="widget" common="1" widgetid="' . $widgetId . '" config="' . $hasAdmin . '" configid="' . $configId . '" serial="' . $serial . '" menu1="' . $menuItem1 . '" >';
 					} else {
-						$menuItem1 = '共通項目に設定';
+						$menuItem1 = 'ページ共通に設定';
 						echo '<div id="' . $widgetTag . '" class="' . self::WIDTET_CLASS_NAME . '" ondblclick="m3DoubleClickWidget(event, this, \'' . $widgetId . '\');" style="background-color:#ffe4c4;margin:2px;padding:10px;border:2px solid #b22222;color:#800000;" context="widget" common="0" widgetid="' . $widgetId . '" config="' . $hasAdmin . '" configid="' . $configId . '" serial="' . $serial . '" menu1="' . $menuItem1 . '" >';
 					}
 					echo '<table class="' . self::WIDTET_CLASS_NAME . '"><tr><td class="' . self::WIDTET_CLASS_NAME . '">' . $imageTag . '</td><td class="' . self::WIDTET_CLASS_NAME . '">';
@@ -1373,11 +1427,18 @@ class PageManager
 		$url = '';
 		if (empty($pageId)){	
 			$url .= $gEnvManager->getCurrentScriptUrl();
+		} else {
+			// URLを設定
+			$pathArray = explode('_', $pageId);
+			for ($i = 0; $i < count($pathArray); $i++){
+				$path .= '/' . $pathArray[$i];
+			}
+			$url = $gEnvManager->getRootUrl() . $path . '.php';
 		}
 		
 		$url .= '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_FIND_WIDGET;
 		$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $toWidgetId;
-		$url .= '&' . M3_REQUEST_PARAM_FROM . '=' . $fromWidgetId;		// 送信元
+		if (!empty($fromWidgetId)) $url .= '&' . M3_REQUEST_PARAM_FROM . '=' . $fromWidgetId;		// 送信元
 		if (!empty($todo)) $url .= '&' . M3_REQUEST_PARAM_OPERATION_TODO . '=' . urlencode($todo);
 		return $url;
 	}
