@@ -190,6 +190,18 @@ class RequestManager
 	{
 		$_SESSION[$name] = $value;
 	}
+	/**
+	 * セッション格納値を開放
+	 *
+	 * $_SESSIONの指定値を開放する
+	 *
+	 * @param string $name		キー値
+	 * @return 					なし
+	 */
+	public function unsetSessionValue($name)
+	{
+		unset($_SESSION[$name]);
+	}
 	/**
 	 * セッションからシリアライズされた値を取得
 	 *
