@@ -16,7 +16,7 @@ CREATE TABLE _system_config (
 ) TYPE=innodb;
 INSERT INTO _system_config (sc_id,                         sc_value, sc_name,                sc_index) VALUES
 ('system_name',                 'Magic3',     'システム名称',                    0),
-('db_version',                  '2008011701', 'DBバージョン',                    1),
+('db_version',                  '2008012401', 'DBバージョン',                    1),
 ('server_id',                   '',           'サーバ識別用ID',                  2),
 ('default_lang',                'ja',         'デフォルト言語',                  3),
 ('multi_language',               '0',          '多言語対応',                      4),
@@ -109,7 +109,7 @@ CREATE TABLE _version (
     PRIMARY KEY          (vs_id)
 ) TYPE=innodb;
 INSERT INTO _version (vs_id,         vs_value,     vs_name)
-VALUES               ('basic_table', '2007122201', '基本テーブルのバージョン');
+VALUES               ('basic_table', '2008013001', '基本テーブルのバージョン');
 
 -- 汎用キー値型パラメータマスター
 DROP TABLE IF EXISTS _key_value;
@@ -121,6 +121,7 @@ CREATE TABLE _key_value (
     kv_value             TEXT           DEFAULT ''                    NOT NULL,      -- 値
     kv_name              VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- 名称
     kv_description       VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 説明
+    kv_group_id          VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 項目グループ識別ID(任意)
     
     kv_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
     kv_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
@@ -364,6 +365,7 @@ CREATE TABLE _templates (
     tm_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
     tm_url               TEXT           DEFAULT ''                    NOT NULL,      -- 取得先URL
     tm_default           BOOLEAN        DEFAULT false                 NOT NULL,      -- デフォルトフラグ
+    tm_mobile            BOOLEAN        DEFAULT false                 NOT NULL,      -- 携帯対応かどうか
     tm_available         BOOLEAN        DEFAULT true                  NOT NULL,      -- メニューから選択可能かどうか
     
     tm_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
@@ -398,8 +400,10 @@ CREATE TABLE _widgets (
     wd_status            INT            DEFAULT 0                     NOT NULL,      -- 状態(0=通常、1=テスト中)
     wd_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
     wd_url               TEXT           DEFAULT ''                    NOT NULL,      -- 取得先URL
+    wd_add_scripts       TEXT           DEFAULT ''                    NOT NULL,      -- 追加スクリプトファイル(「,」区切りで複数指定可)
+    wd_mobile            BOOLEAN        DEFAULT false                 NOT NULL,      -- 携帯対応かどうか
     wd_show_name         BOOLEAN        DEFAULT false                 NOT NULL,      -- ウィジェット名称を表示するかどうか
-    wd_read_scripts      BOOLEAN        DEFAULT false                 NOT NULL,      -- スクリプトファイルを読み込むかどうか
+    wd_read_scripts      BOOLEAN        DEFAULT false                 NOT NULL,      -- スクリプトディレクトリを自動読み込みするかどうか
     wd_read_css          BOOLEAN        DEFAULT false                 NOT NULL,      -- cssファイルを読み込むかどうか
     wd_use_ajax          BOOLEAN        DEFAULT false                 NOT NULL,      -- Ajax共通ライブラリを読み込むかどうか
     wd_available         BOOLEAN        DEFAULT true                  NOT NULL,      -- メニューから選択可能かどうか
