@@ -105,6 +105,7 @@ CREATE TABLE menu_item (
 DROP TABLE IF EXISTS content;
 CREATE TABLE content (
     cn_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    cn_type              VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- コンテンツタイプ
     cn_id                INT            DEFAULT 0                     NOT NULL,      -- コンテンツID
     cn_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
     cn_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
@@ -126,7 +127,7 @@ CREATE TABLE content (
     cn_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
     cn_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
     PRIMARY KEY          (cn_serial),
-    UNIQUE               (cn_id,        cn_language_id,               cn_history_index)
+    UNIQUE               (cn_type,      cn_id,        cn_language_id,               cn_history_index)
 ) TYPE=innodb;
 
 -- ブログ設定マスター
@@ -199,7 +200,7 @@ CREATE TABLE bbs_config (
     PRIMARY KEY          (sf_id)
 ) TYPE=innodb;
 INSERT INTO bbs_config (sf_id,                     sf_value,    sf_name,                        sf_index)
-VALUES                 ('use_email',               '0',         'Eメール送信機能',              1);
+VALUES                 ('use_email',               '1',         'Eメール送信機能',              1);
 INSERT INTO bbs_config (sf_id,                     sf_value,    sf_name,                        sf_index)
 VALUES                 ('send_password_on_regist', '0',         '会員登録時のEメール自動送信',  2);
 INSERT INTO bbs_config (sf_id,                     sf_value,    sf_name,                        sf_index)
@@ -517,16 +518,25 @@ INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author,
 DELETE FROM _widgets WHERE wd_id = 'ec_main';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('ec_main',            'Eコマース - メイン',         'ECOM', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10,          false,           false,       true,         true,        true,         true,               false,true,           0, now(), now());
+DELETE FROM _widgets WHERE wd_id = 'ec_menu';
+INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('ec_menu',   'Eコマース - 商品メニュー',   'ECMN', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10,          false,           false,       true,         true,        true,         false,               false,true,           0, now(), now());
 DELETE FROM _widgets WHERE wd_id = 'ec_category_menu';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('ec_category_menu',   'Eコマース - カテゴリーメニュー', 'ECCM', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10,          false,           false,       true,         true,        true,         false,               false,true,           0, now(), now());
 DELETE FROM _widgets WHERE wd_id = 'ec_cart_box';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('ec_cart_box',        'Eコマース - カート',     'ECCT', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10,          false,           false,       true,         true,        false,         false,               false,true,           100, now(),      now());
+DELETE FROM _widgets WHERE wd_id = 'ec_product_header';
+INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('ec_product_header',               'Eコマース - 商品ヘッダ',                   'ECHD', '1.0.0',  '',  'Naoki Hirata', 'Magic3.org', 'GPL', 10,      false,           false,       true,         true,        false,        false,               false,true,           0, now(), now());
 DELETE FROM _widgets WHERE wd_id = 'ec_product_display';
 INSERT INTO _widgets
 (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('ec_product_display',            'Eコマース - 新着おすすめ',         'ECPD', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10,          false,           false,       true,         true,        true,         false,               true,true,           0, now(), now());
+DELETE FROM _widgets WHERE wd_id = 'ec_search_box';
+INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('ec_search_box',   'Eコマース - 検索',            'ECSR', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10,         false,           false,       true,         true,        false,         false,               false,true,               0, now(),    now());
 DELETE FROM _widgets WHERE wd_id = 'yahoo_weather';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('yahoo_weather',      'Yahooお天気',                'YWEA', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10,          false,           false,       true,         true,        false,        false,               false,true,               0, now(),   now());
@@ -597,7 +607,17 @@ VALUES                 ('browns',                 'browns',      '',
 INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
 VALUES                 ('red_rose_beauty',        'red_rose_beauty',      '',             false,      now());
 INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
-VALUES                 ('ec_simple',              'ec_simple',              '',             false,      now());
+VALUES                 ('ec_simple_n2',           'ec_simple_n2',           '',             false,      now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
+VALUES                 ('ec_simple_n2_pink',      'ec_simple_n2_pink',      '',             false,      now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
+VALUES                 ('ec_simple_n3',           'ec_simple_n3',           '',             false,      now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
+VALUES                 ('ec_simple_n3_aqua',      'ec_simple_n3_aqua',      '',             false,      now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
+VALUES                 ('ec_simple_w2',           'ec_simple_w2',           '',             false,      now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
+VALUES                 ('ec_simple_w3',           'ec_simple_w3',           '',             false,      now());
 
 -- 基本テーブルの不要なデータを削除
 -- 画面定義
