@@ -251,3 +251,15 @@ function m3UpdateParentWindow()
 {
 	window.opener.location.href = window.opener.location.href;
 }
+// ウィンドウサイズ調整
+function m3AdjustHeight(id, name)
+{
+	var app = navigator.appName.charAt(0);
+	if(navigator.userAgent.indexOf('Safari') != -1){
+		$(id).height = parent.frames[name].document.body.scrollHeight + 80;
+	}else if (app == "N"){
+		$(id).height = parent.frames[name].document.height +80;
+	} else {
+		$(id).height = parent.frames[name].document.body.scrollHeight + 80;
+	}
+}
