@@ -27,7 +27,7 @@ class admin_mainPagedefWidgetContainer extends BaseWidgetContainer
 	private $addPos;	// 追加表示ポジション
 	private $addWidgetId; // 追加ウィジェットID
 	private $defaultPageSubId;		// デフォルトのページID
-	private $defaultImageSize = 64;		// ウィジェット画像サイズ
+	private $defaultImageSize = 32;		// ウィジェット画像サイズ
 	private $widgetArray = array();
 	private $templateId;		// テンプレートID
 	private $delAllButtonEnabled = true;		// すべて削除ボタンの状態
@@ -517,6 +517,9 @@ class admin_mainPagedefWidgetContainer extends BaseWidgetContainer
 			}
 		}
 		
+		// ウィジェット名
+		$name = $this->convertToDispString($fetchedRow['wd_name']);
+		
 		// ウィジェットの画像を設定
 		$image = $gDesignManager->getWidgetIconUrl($id, $this->defaultImageSize);
 		$imageTag = '<img class="widget_obj" src="' . $image . '" ';
@@ -524,6 +527,8 @@ class admin_mainPagedefWidgetContainer extends BaseWidgetContainer
 		$imageTag .= ' height="' . $this->defaultImageSize . '"';
 		$imageTag .= ' />';
 		
+		$message = '<b>' . $name . '</b><br>' . $id;
+		$imageTag = '<span class="tooltip_text" href="#" onmousemove="showToolTip(event,\'' . $message . '\');return false" onmouseout="hideToolTip();">' . $imageTag . '</span>';
 		$row = array(
 			'line_color' => $lineColor,											// 行のカラー
 			'no' => $index + 1,													// 行番号
@@ -531,7 +536,7 @@ class admin_mainPagedefWidgetContainer extends BaseWidgetContainer
 			'id' => $id,			// ID
 			'widget_id' => 'widget_' . $id,
 			'id_text' => $idText,
-			'name' => $this->convertToDispString($fetchedRow['wd_name']),		// 名前
+			'name' => $name,		// 名前
 			'image_tag' => $imageTag		// 画像
 		);
 		$this->tmpl->addVars('widgetlist', $row);
