@@ -144,13 +144,13 @@ class admin_mainTopWidgetContainer extends BaseWidgetContainer
 				}
 			}
 		}
+		/*
+		// ログアウトメニュー項目
 		$menuInner .= '<li class="toppage-menu">';
 		$menuInner .= '<a href="#" onclick="menuLogout();">ログアウト</a>' . M3_NL;
 		$menuInner .= str_repeat(' ', 4);
-/*		$menuInner .= '<ul>' . M3_NL;
-		$menuInner .= str_repeat(' ', 4);
-		$menuInner .= '</ul>' . M3_NL;*/
-		$menuInner .= '</li>' . M3_NL;
+		$menuInner .= '</li>' . M3_NL;*/
+		
 		$menuInner .= '</td></tr>';
 		$this->tmpl->addVar("_widget", "items", $menuInner);
 		
