@@ -57,7 +57,11 @@ class admin_mainWidgetContainer extends BaseWidgetContainer
 				if ($gEnvManager->isSystemAdmin()){	// システム管理者の場合
 					// 表示画面を決定
 					$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
-					if (empty($task)) $task = 'top';
+					if (empty($task)){
+						$task = 'top';
+					} else if ($task == 'userlist_detail'){		// ユーザ詳細
+						$task = 'userlist';
+					}
 					
 					// $taskが「configwidget_xxxx」タイプの場合の処理
 					if (strncmp($task, 'configwidget_', strlen('configwidget_')) == 0){
@@ -78,9 +82,13 @@ class admin_mainWidgetContainer extends BaseWidgetContainer
 						case 'configsite':	// サイト情報
 						case 'configwidget':	// ウィジェット定義
 						case 'editsource':	// ソース編集
+						case 'usercustom':	// ユーザ定義値管理
 						case 'phpinfo':		// phpinfoを出力
 							$gLaunchManager->goSubWidget($task);
 							return false;
+						case 'logout':		// ログアウト処理
+							$logoutPage = $gEnvManager->createCurrentPageUrl() . '&cmd=logout';
+							$gPageManager->redirect($logoutPage);
 						default:
 							$this->SetMsg(0, "アクセスできません");
 							$param = 'message';			// メッセージ画面表示
