@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -818,9 +818,10 @@ class admin_mainDb extends BaseDb
 	 * @param bool    $isAdmin		管理者権限があるかどうか
 	 * @param bool    $canLogin		ログインできるかどうか
 	 * @param int     $userId		更新者ユーザID
+	 * @param int     $newSerial	新規シリアル番号
 	 * @return						true=成功、false=失敗
 	 */
-	function addNewUser($name, $account, $password, $isAdmin, $canLogin, $userId)
+	function addNewUser($name, $account, $password, $isAdmin, $canLogin, $userId, &$newSerial)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 				
@@ -860,6 +861,11 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   '?) ';
 		$this->execStatement($queryStr, array($newId, 0, $name, $account, $password, $userType, $canLogin, $userId, $now));
 		
+		// 新規のシリアル番号取得
+		$queryStr = 'select max(lu_serial) as ns from _login_user ';
+		$ret = $this->selectRecord($queryStr, array(), $row);
+		if ($ret) $newSerial = $row['ns'];
+		
 		// トランザクション確定
 		$ret = $this->endTransaction();
 		return $ret;
@@ -899,13 +905,58 @@ class admin_mainDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * ユーザの削除
+	 *
+	 * @param array $serial			シリアルNo
+	 * @return						true=成功、false=失敗
+	 */
+	function delUserBySerial($serial)
+	{
+		global $gEnvManager;
+			
+		// 引数のエラーチェック
+		if (!is_array($serial)) return false;
+		if (count($serial) <= 0) return true;
+		
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		
+		// トランザクション開始
+		$this->startTransaction();
+		
+		// 指定のシリアルNoのレコードが削除状態でないかチェック
+		for ($i = 0; $i < count($serial); $i++){
+			$queryStr  = 'SELECT * FROM _login_user ';
+			$queryStr .=   'WHERE lu_deleted = false ';		// 未削除
+			$queryStr .=     'AND lu_serial = ? ';
+			$ret = $this->isRecordExists($queryStr, array($serial[$i]));
+			// 存在しない場合は、既に削除されたとして終了
+			if (!$ret){
+				$this->endTransaction();
+				return false;
+			}
+		}
+		
+		// レコードを削除
+		$queryStr  = 'UPDATE _login_user ';
+		$queryStr .=   'SET lu_deleted = true, ';	// 削除
+		$queryStr .=     'lu_update_user_id = ?, ';
+		$queryStr .=     'lu_update_dt = ? ';
+		$queryStr .=   'WHERE lu_serial in (' . implode($serial, ',') . ') ';
+		$this->execStatement($queryStr, array($userId, $now));
+		
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return $ret;
+	}
 	/**
 	 * ユーザの更新
 	 *
 	 * @param int $serial			シリアル番号
 	 * @param string  $name			ユーザ名
 	 * @param string  $account		アカウント
-	 * @param string  $password		パスワード
+	 * @param string  $password		パスワード(空のときは更新しない)
 	 * @param bool $isAdmin			管理者権限があるかどうか
 	 * @param string $canLogin		ログイン可能かどうか
 	 * @param int $userId			ユーザID
@@ -939,6 +990,10 @@ class admin_mainDb extends BaseDb
 		$userType = UserInfo::USER_TYPE_NORMAL;		// 一般ユーザ
 		if ($isAdmin) $userType = UserInfo::USER_TYPE_SYS_ADMIN;		// 管理ユーザ
 		
+		// パスワードが設定されているときは更新
+		$pwd = $row['lu_password'];
+		if (!empty($password)) $pwd = $password;
+		
 		// 古いレコードを削除
 		$queryStr  = 'UPDATE _login_user ';
 		$queryStr .=   'SET lu_deleted = true, ';	// 削除
@@ -972,7 +1027,7 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
 		$queryStr .=   '?) ';
-		$this->execStatement($queryStr, array($row['lu_id'], $historyIndex, $name, $account, $password, $userType, $row['lu_subject'], $row['lu_widget_id'], $canLogin, $userId, $now));
+		$this->execStatement($queryStr, array($row['lu_id'], $historyIndex, $name, $account, $pwd, $userType, $row['lu_subject'], $row['lu_widget_id'], $canLogin, $userId, $now));
 
 		// 新規のシリアル番号取得
 		$queryStr = 'select max(lu_serial) as ns from _login_user ';
@@ -1324,5 +1379,22 @@ class admin_mainDb extends BaseDb
 		$retValue = $this->selectRecords($queryStr, array($navId, $parentId), $rows);
 		return $retValue;
 	}
+	/**
+	 * 変換キーテーブルを取得
+	 *
+	 * @param string	$key				キー文字列
+	 * @param string	$group				グループID
+	 * @param function	$callback			コールバック関数
+	 * @return 			なし
+	 */
+	function getAllKey($key, $group, $callback)
+	{
+		$queryStr = 'SELECT * FROM _key_value ';
+		$queryStr .=  'WHERE kv_deleted = false ';
+		$queryStr .=    'AND kv_id LIKE \'' . $key . '%\' ';
+		$queryStr .=    'AND kv_group_id = ? ';
+		$queryStr .=  'ORDER BY kv_id';
+		$this->selectLoop($queryStr, array($group), $callback, null);
+	}
 }
 ?>
