@@ -37,7 +37,7 @@ class admin_ec_mainBaseWidgetContainer extends BaseWidgetContainer
 	function _postAssign($request, &$param)
 	{
 		global $gEnvManager;
-		
+
 		// 表示画面を決定
 		$task = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_TASK);
 		if (empty($task)) $task = 'top';
@@ -48,33 +48,42 @@ class admin_ec_mainBaseWidgetContainer extends BaseWidgetContainer
 				$linkList = '';// パンくずリスト
 				break;
 			case 'category':	// 商品カテゴリ管理
-				$linkList = ' &gt;&gt; カテゴリー管理 &gt;&gt; カテゴリーマスター';// パンくずリスト
-				break;
-			case 'product':		// 商品管理
-				$linkList = ' &gt;&gt; 商品管理 &gt;&gt; 商品マスター';// パンくずリスト
+			case 'category_detail':	// 商品カテゴリ管理(詳細)
+				$linkList = ' &gt;&gt; カテゴリー管理 &gt;&gt; カテゴリー一覧';// パンくずリスト
 				break;
 			case 'productlist':		// 商品管理
 				$linkList = ' &gt;&gt; 商品管理 &gt;&gt; 商品一覧';// パンくずリスト
 				break;
+			case 'product':		// 商品管理
+				$linkList = ' &gt;&gt; 商品管理 &gt;&gt; 商品詳細';// パンくずリスト
+				break;
 			case 'productcsv':		// 商品管理
 				$linkList = ' &gt;&gt; 商品管理 &gt;&gt; CSVデータ';// パンくずリスト
 				break;
 			case 'order':		// 受注管理
-				$linkList = ' &gt;&gt; 受注管理 &gt;&gt; 受注マスター';// パンくずリスト
+			case 'order_detail':		// 受注管理(詳細)
+				$linkList = ' &gt;&gt; 受注管理 &gt;&gt; 受注一覧';// パンくずリスト
 				break;
 			case 'member':		// 会員管理
-				$linkList = ' &gt;&gt; 会員管理 &gt;&gt; 会員マスター';// パンくずリスト
+			case 'member_detail':		// 会員管理(詳細)
+				$linkList = ' &gt;&gt; 会員管理 &gt;&gt; 会員一覧';// パンくずリスト
+				break;
+			case 'membercsv':		// 会員CSVデータ
+				$linkList = ' &gt;&gt; 会員管理 &gt;&gt; CSVデータ';// パンくずリスト
 				break;
 			/*case 'shopinfo':		// ショップ情報
 				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; ショップ情報';// パンくずリスト
 				break;*/
 			case 'paymethod':		// 支払方法
+			case 'paymethod_detail':		// 支払方法(詳細)
 				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; 支払方法';// パンくずリスト
 				break;
 			case 'delivmethod':		// 配送方法
+			case 'delivmethod_detail':		// 配送方法(詳細)
 				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; 配送方法';// パンくずリスト
 				break;
-			case 'init':		// 文字列変換設定
+			case 'keyword':		// 文字列変換設定
+			case 'keyword_detail':		// 文字列変換設定(詳細)
 				$linkList = ' &gt;&gt; 基本設定 &gt;&gt; 置換文字列編集';// パンくずリスト
 				break;
 			case 'imageupload':		// 画像アップロード
@@ -89,22 +98,23 @@ class admin_ec_mainBaseWidgetContainer extends BaseWidgetContainer
 		$menuText .= '<ul>' . M3_NL;
 		
 		$current = '';
-		$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+		$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId();
 				
 		// カテゴリー管理
 		$current = '';
-		$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+		$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=category';
-		if ($task == 'category'){		
+		if ($task == 'category' ||
+			$task == 'category_detail'){		
 			$current = 'id="current"';
 		}
 		$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>カテゴリー管理</span></a></li>' . M3_NL;
 		
 		// 商品管理
 		$current = '';
-		$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
-				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=product';
+		$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=productlist';
 		if ($task == 'product' || 		// 商品詳細
 			$task == 'productlist' || 	// 商品一覧
 			$task == 'productcsv' ||		// CSVデータ
@@ -115,30 +125,36 @@ class admin_ec_mainBaseWidgetContainer extends BaseWidgetContainer
 		
 		// 受注管理
 		$current = '';
-		$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+		$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=order';
-		if ($task == 'order'){
+		if ($task == 'order' ||
+			$task == 'order_detail'){
 			$current = 'id="current"';
 		}
 		$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>受注管理</span></a></li>' . M3_NL;
 		
 		// 会員管理
 		$current = '';
-		$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+		$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=member';
-		if ($task == 'member'){
+		if ($task == 'member' ||
+			$task == 'member_detail' ||
+			$task == 'membercsv'	){			// 会員CSVデータ
 			$current = 'id="current"';
 		}
 		$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>会員管理</span></a></li>' . M3_NL;
 		
 		// 基本設定
 		$current = '';
-		$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
-				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=init';
+		$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=keyword';
 		if ($task == 'shopinfo' ||		// ショップ情報
 			$task == 'paymethod' ||		// 支払方法
+			$task == 'paymethod_detail' ||		// 支払方法(詳細)
 			$task == 'delivmethod' ||		// 配送方法
-			$task == 'init' ||		// 文字列変換設定
+			$task == 'delivmethod_detail' ||		// 配送方法(詳細)
+			$task == 'keyword' ||		// 文字列変換設定
+			$task == 'keyword_detail' ||		// 文字列変換設定(詳細)
 			$task == 'other'){		// その他設定
 			$current = 'id="current"';
 		}
@@ -152,95 +168,109 @@ class admin_ec_mainBaseWidgetContainer extends BaseWidgetContainer
 		$menuText .= '<div id="configmenu-lower">' . M3_NL;
 		$menuText .= '<ul>' . M3_NL;
 
-		if ($task == 'category'){	// 商品カテゴリ管理
+		if ($task == 'category' ||
+			$task == 'category_detail'){	// 商品カテゴリ管理
 			// 商品カテゴリ
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=category';
 			if ($task == 'category') $current = 'id="current"';
-			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>カテゴリーマスター</span></a></li>' . M3_NL;
+			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>カテゴリー一覧</span></a></li>' . M3_NL;
 		} else if ($task == 'product' || 		// 商品詳細
 			$task == 'productlist' || 	// 商品一覧
 			$task == 'productcsv' ||	// CSVデータ
 			$task == 'imageupload'){		// 画像アップロード
-			// 商品詳細
-			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
-					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=product';
-			if ($task == 'product') $current = 'id="current"';
-			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>商品マスター</span></a></li>' . M3_NL;
-			
 			// 商品一覧
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=productlist';
 			if ($task == 'productlist') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>商品一覧</span></a></li>' . M3_NL;
 			
+			// 商品詳細
+			$current = '';
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=product';
+			if ($task == 'product') $current = 'id="current"';
+			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>商品詳細</span></a></li>' . M3_NL;
+			
 			// CSVデータ
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=productcsv';
 			if ($task == 'productcsv') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>CSVデータ</span></a></li>' . M3_NL;
 			
 			// 画像アップロード
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=imageupload';
 			if ($task == 'imageupload') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>画像アップロード</span></a></li>' . M3_NL;
-		} else if ($task == 'order'){	// 受注管理
-			// 受注マスター
+		} else if ($task == 'order' ||
+					$task == 'order_detail'){	// 受注管理
+			// 受注一覧
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=order';
 			if ($task == 'order') $current = 'id="current"';
-			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>受注マスター</span></a></li>' . M3_NL;
-		} else if ($task == 'member'){	// 会員管理
-			// 会員マスター
+			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>受注一覧</span></a></li>' . M3_NL;
+		} else if ($task == 'member' ||
+					$task == 'member_detail' ||
+					$task == 'membercsv'){	// 会員管理
+			// 会員一覧
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=member';
-			if ($task == 'member') $current = 'id="current"';
-			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>会員マスター</span></a></li>' . M3_NL;
+			if ($task == 'member' || $task == 'member_detail') $current = 'id="current"';
+			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>会員一覧</span></a></li>' . M3_NL;
+			
+			// 会員CSV
+			$current = '';
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=membercsv';
+			if ($task == 'membercsv') $current = 'id="current"';
+			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>CSVデータ</span></a></li>' . M3_NL;
 		} else if ($task == 'shopinfo' ||		// ショップ情報
 			$task == 'paymethod' ||		// 支払方法
+			$task == 'paymethod_detail' ||		// 支払方法(詳細)
 			$task == 'delivmethod' ||		// 配送方法
-			$task == 'init' ||		// 文字列変換設定
+			$task == 'delivmethod_detail' ||		// 配送方法(詳細)
+			$task == 'keyword' ||		// 文字列変換設定
+			$task == 'keyword_detail' ||		// 文字列変換設定(詳細)
 			$task == 'other'){		// その他
 			
 			// ショップ情報
 			/*$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=shopinfo';
 			if ($task == 'shopinfo') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>ショップ情報</span></a></li>' . M3_NL;*/
 		
 			// 置換文字列編集
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
-					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=init';
-			if ($task == 'init') $current = 'id="current"';
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=keyword';
+			if ($task == 'keyword' || $task == 'keyword_detail') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>置換文字列編集</span></a></li>' . M3_NL;
 			
 			// 配送方法
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=delivmethod';
-			if ($task == 'delivmethod') $current = 'id="current"';
+			if ($task == 'delivmethod' || $task == 'delivmethod_detail') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>配送方法</span></a></li>' . M3_NL;
 		
 			// 支払方法
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=paymethod';
-			if ($task == 'paymethod') $current = 'id="current"';
+			if ($task == 'paymethod' || $task == 'paymethod_detail') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>支払方法</span></a></li>' . M3_NL;
 			
 			// 商品表示設定
 			$current = '';
-			$link = $gEnvManager->getAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+			$link = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
 					'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=other';
 			if ($task == 'other') $current = 'id="current"';
 			$menuText .= '<li ' . $current . '><a href="'. $link .'"><span>その他</span></a></li>' . M3_NL;
