@@ -26,16 +26,16 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 	private $firstNo;			// 項目番号
 	private $state;				// 都道府県
 	private $memberType;		// 会員タイプ
-	private $csvData;			// CSVデータ
 	private $ecMailObj;	// メール連携オブジェクト
+	private $serialArray = array();		// 表示されている項目シリアル番号
 	const EC_LIB_ID = "eclib";		// EC共通ライブラリオブジェクトID
 	const DEFAULT_COUNTRY_ID = 'JPN';	// デフォルト国ID
 	const DEFAULT_LIST_COUNT = 20;			// 最大リスト表示数
 	const USE_EMAIL		= 'use_email';		// EMAIL機能が使用可能かどうか
 	const SEND_PASSWORD_FORM = 'send_password';		// パスワード送信用フォーム
 	const AUTO_EMAIL_SENDER	= 'auto_email_sender';		// 自動送信メール用送信者アドレス
-	const CSV_FILE_HEAD = 'member_';		// CSVファイル名
 	const MAIL_OBJ_ID = 'ecmail';			// メール連携オブジェクト
+	const TARGET_WIDGET = 'ec_main';		// パスワード送信後にログインするための画面呼び出しウィジェットID
 	// メール連携用定義
 //	const USE_EMAIL_TO_BACKOFFICE	= 'use_email_to_backoffice';		// EMAIL連携機能が使用可能かどうか
 //	const MAIL_TO_MEMBER_REGIST		= 'mail_to_member_regist';		// メール送信先(会員登録)
@@ -72,9 +72,9 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 	 */
 	function _setTemplate($request, &$param)
 	{
-		$act = $request->trimValueOf('act');
-		if ($act == 'download'){		// CSVダウンロード
-			return '';
+		$task = $request->trimValueOf('task');
+		if ($task == 'member_detail'){		// 詳細画面
+			return 'admin_member_detail.tmpl.html';
 		} else {
 			return 'admin_member.tmpl.html';
 		}
@@ -89,33 +89,133 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 	 * @param								なし
 	 */
 	function _assign($request, &$param)
+	{
+		$task = $request->trimValueOf('task');
+		if ($task == 'member_detail'){	// 詳細画面
+			return $this->createDetail($request);
+		} else {			// 一覧画面
+			return $this->createList($request);
+		}
+	}
+	/**
+	 * 一覧画面作成
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param								なし
+	 */
+	function createList($request)
 	{
 		global $gEnvManager;
-		global $gMailManager;
-		global $gSystemManager;
-		global $gInstanceManager;
-
-		$now = date("Y/m/d H:i:s");	// 現在日時
 		
-		// ユーザ情報、表示言語
-		$userId		= $gEnvManager->getCurrentUserId();
-		$langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
-		$countryId = self::DEFAULT_COUNTRY_ID;			// デフォルト国ID
-				
-		$act = $request->trimValueOf('act');
-		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
-		if (empty($this->serialNo)) $this->serialNo = 0;
 		$pageNo = $request->trimValueOf('page');				// ページ番号
 		if (empty($pageNo)) $pageNo = 1;
+		$this->memberType	= $request->trimValueOf('member_type');				// 会員タイプ
 		
-		// DBの保存設定値を取得
+		// デフォルト値を取得
 		$maxListCount = self::DEFAULT_LIST_COUNT;
 		$serializedParam = $this->sysDb->getWidgetParam($gEnvManager->getCurrentWidgetId());
 		if (!empty($serializedParam)){
 			$dispInfo = unserialize($serializedParam);
 			$maxListCount = $dispInfo->maxMemberListCountByAdmin;		// 会員リスト最大表示数
 		}
+		$act = $request->trimValueOf('act');
+		if ($act == 'delete'){		// 項目削除の場合
+			$listedItem = explode(',', $request->trimValueOf('seriallist'));
+			$delItems = array();
+			for ($i = 0; $i < count($listedItem); $i++){
+				// 項目がチェックされているかを取得
+				$itemName = 'item' . $i . '_selected';
+				$itemValue = ($request->trimValueOf($itemName) == 'on') ? 1 : 0;
+				
+				if ($itemValue){		// チェック項目
+					$delItems[] = $listedItem[$i];
+				}
+			}
+			if (count($delItems) > 0){
+				//$ret = $this->db->deleteDelivMethodDefBySerial($delItems);
+				for ($i = 0; $i < count($delItems); $i++){
+					$ret = $this->deleteUser($delItems[$i]);
+					if (!$ret) break;
+				}
+				if ($ret){		// データ削除成功のとき
+					$this->setGuidanceMsg('データを削除しました');
+				} else {
+					$this->setAppErrorMsg('データ削除に失敗しました');
+				}
+			}
+		}
 		
+		// 会員タイプ
+		if (empty($this->memberType)){		// 正会員のとき
+			$this->tmpl->addVar("_widget", "member_regular", 'selected');
+		} else {
+			$this->tmpl->addVar("_widget", "member_tmp", 'selected');
+		}
+		
+		// ###### 会員一覧を作成 #####
+		if (empty($this->memberType)){		// 正会員のとき
+			// 総数を取得
+			$totalCount = $this->db->getMemberCount(0);
+		} else {
+			// 総数を取得
+			$totalCount = $this->db->getMemberCount(1);
+		}
+		
+		// 表示するページ番号の修正
+		$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
+		if ($pageNo < 1) $pageNo = 1;
+		if ($pageNo > $pageCount) $pageNo = $pageCount;
+		$this->firstNo = ($pageNo -1) * $maxListCount + 1;		// 先頭番号
+		
+		if (empty($this->memberType)){		// 正会員のとき
+			// 会員リストを表示
+			$this->db->getMemberList(0, $maxListCount, ($pageNo -1) * $maxListCount, array($this, 'memberListLoop'));
+		} else {
+			// 仮会員リストを表示
+			$this->db->getMemberList(1, $maxListCount, ($pageNo -1) * $maxListCount, array($this, 'memberListLoop'));
+		}
+		
+		// ページング用リンク作成
+		$pageLink = '';
+		if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
+			for ($i = 1; $i <= $pageCount; $i++){
+				//$linkUrl = $this->currentPageUrl . '&category=' . $this->categoryId . '&page=' . $i;
+				if ($i == $pageNo){
+					$link = '&nbsp;' . $i;
+				} else {
+					//$link = '&nbsp;<a href="' . $linkUrl . '" >' . $i . '</a>';
+					$link = '&nbsp;<a href="#" onclick="selpage(\'' . $i . '\');return false;">' . $i . '</a>';
+				}
+				$pageLink .= $link;
+			}
+		}
+		$this->tmpl->addVar("_widget", "page_link", $pageLink);
+		$this->tmpl->addVar("_widget", "page", $pageNo);		// 現在のページ番号
+		
+		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
+	}
+	/**
+	 * 詳細画面作成
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param								なし
+	 */
+	function createDetail($request)
+	{
+		global $gEnvManager;
+		global $gMailManager;
+		global $gSystemManager;
+		global $gInstanceManager;
+		global $gPageManager;
+
+		// ユーザ情報、表示言語
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId		= $gEnvManager->getCurrentUserId();
+		$langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
+		$countryId = self::DEFAULT_COUNTRY_ID;			// デフォルト国ID
+				
+		$act = $request->trimValueOf('act');
+		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
 		$this->memberType	= $request->trimValueOf('member_type');				// 会員タイプ
 		$memberNo			= $request->trimValueOf('member_no');			// 会員No
 		$email				= $request->trimValueOf('email');			// eメール(ログインアカウント)
@@ -133,36 +233,11 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		$address2			= $request->trimValueOf('address2');			// 住所2
 		$phone				= $request->trimValueOf('phone');			// 電話番号
 		$fax				= $request->trimValueOf('fax');				// FAX
-		$withLoginUser		= ($request->trimValueOf('withloginuser') == 'on') ? 1 : 0;		// ログインアカウントも削除するかどうか
+		//$withLoginUser		= ($request->trimValueOf('withloginuser') == 'on') ? 1 : 0;		// ログインアカウントも削除するかどうか
+		$withLoginUser = 1;			// 常にログインアカウントは削除に設定
 				
 		$replaceNew = false;		// データを再取得するかどうか
-		if ($act == 'select'){		// 項目選択の場合
-			if ($this->serialNo == 0){		// シリアル番号が0のときは、新規追加モードにする
-				// 入力値初期化
-				$memberNo = '';			// 会員No
-				$email = '';			// eメール(ログインアカウント)
-				$mobile = '';			// 携帯電話
-				$gender = 0;			// 性別
-				$birthday = '';			// 生年月日
-				$familyName = '';		// 会員名(姓)
-				$firstName = '';		// 会員名(名)
-				$familyNameKana = '';		// 会員名カナ(姓)
-				$firstNameKana = '';		// 会員名カナ(名)
-				$zipcode = '';				// 郵便番号
-				$this->state = 0;					// 都道府県
-				$address = '';			// 住所
-				$address2 = '';			// 住所2
-				$phone = '';			// 電話番号
-				$fax = '';				// FAX
-				$updateUser = '';	// 更新者
-				$updateDt = '';	// 更新日時
-				
-				// 会員NOのデフォルト値を自動生成
-				$memberNo = $gInstanceManager->getObject(self::EC_LIB_ID)->generateMemberNo();
-			} else {
-				$replaceNew = true;			// 会員情報を再取得
-			}
-		} else if ($act == 'add'){		// 項目追加の場合
+		if ($act == 'add'){		// 項目追加の場合
 			// 入力チェック
 			$this->checkInput($familyName, '会員名(姓)');
 			$this->checkInput($firstName, '会員名(名)');
@@ -279,6 +354,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			}
 			// エラーなしの場合は、データを削除
 			if ($this->getMsgCount() == 0){
+				/*
 				// ログインユーザIDを取得
 				if (empty($this->memberType)){		// 正会員のとき
 					if ($this->db->getMemberBySerial(0, $this->serialNo, $row)) $loginUserId = $row['sm_login_user_id'];
@@ -292,7 +368,8 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 				}
 				if ($withLoginUser){		// ログインユーザも削除のとき
 					if ($ret) $this->sysDb->delLoginUser($loginUserId);
-				}
+				}*/
+				$ret = $this->deleteUser($this->serialNo);
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
 					
@@ -302,48 +379,7 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 					$this->setAppErrorMsg('データ削除に失敗しました');
 				}
 			}
-		} else if ($act == 'selmembertype'){	// 会員種別選択
-			$this->serialNo = 0;
-			
-			// 入力値初期化
-			$memberNo = '';			// 会員No
-			$email = '';			// eメール(ログインアカウント)
-			$mobile = '';			// 携帯電話
-			$gender = 0;			// 性別
-			$birthday = '';			// 生年月日
-			$familyName = '';		// 会員名(姓)
-			$firstName = '';		// 会員名(名)
-			$familyNameKana = '';		// 会員名カナ(姓)
-			$firstNameKana = '';		// 会員名カナ(名)
-			$zipcode = '';				// 郵便番号
-			$this->state = 0;					// 都道府県
-			$address = '';			// 住所
-			$address2 = '';			// 住所2
-			$phone = '';			// 電話番号
-			$fax = '';				// FAX
-			$updateUser = '';	// 更新者
-			$updateDt = '';	// 更新日時
 		} else if ($act == 'search'){		// 検索再実行
-			$this->serialNo = 0;
-			
-			// 入力値初期化
-			$memberNo = '';			// 会員No
-			$email = '';			// eメール(ログインアカウント)
-			$mobile = '';			// 携帯電話
-			$gender = 0;			// 性別
-			$birthday = '';			// 生年月日
-			$familyName = '';		// 会員名(姓)
-			$firstName = '';		// 会員名(名)
-			$familyNameKana = '';		// 会員名カナ(姓)
-			$firstNameKana = '';		// 会員名カナ(名)
-			$zipcode = '';				// 郵便番号
-			$this->state = 0;					// 都道府県
-			$address = '';			// 住所
-			$address2 = '';			// 住所2
-			$phone = '';			// 電話番号
-			$fax = '';				// FAX
-			$updateUser = '';	// 更新者
-			$updateDt = '';	// 更新日時
 		} else if ($act == 'sendpassword'){	// パスワードを送信
 			$useEmail = $this->mainDb->getConfig(self::USE_EMAIL);
 			if ($useEmail == '1'){		// メール送信可能のとき
@@ -360,25 +396,20 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 						$loginUserId = $row['sb_login_user_id'];
 					}
 					// パスワードを送信するときは、常に再作成する
-					//$password = '';
-					//$recreatePwd = ($request->trimValueOf('recreatepwd') == 'on') ? 1 : 0;				// パスワード再作成
-					//if ($recreatePwd){		// パスワード再作成のとき
-						// パスワード作成
-						$password = $this->makePassword();
-						
-						// パスワード変更
-						$ret = $this->sysDb->updateLoginUserPassword($loginUserId, $password);
-					//} else {		// パスワード再送のとき
-					//	$ret = $this->sysDb->getLoginUserRecordById($loginUserId, $loginUserRow);
-					//	if ($ret) $password = $loginUserRow['lu_password'];
-					//}
+					$password = $this->makePassword();// パスワード作成
+					
+					// パスワード変更
+					$ret = $this->sysDb->updateLoginUserPassword($loginUserId, $password);
 					if ($ret){
 						$fromAddress = $this->mainDb->getConfig(self::AUTO_EMAIL_SENDER);	// 自動送信送信元
 						if (empty($fromAddress)) $fromAddress = $gEnvManager->getSiteEmail();// 送信元が取得できないときは、システムのデフォルトメールアドレスを使用
 						$toAddress = $this->convertToDispString($row['pi_email']);			// eメール(ログインアカウント)
+						$loginParam = 'task=login&act=ec_maillogin&account=' . urlencode($toAddress) . '&pwd=' . urlencode($password);// ログイン用パラメータ
+						$url = $gPageManager->createWidgetCmdUrl('index', self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, $loginParam);
 						$mailParam = array();
 						$mailParam['PASSWORD'] = $password;
-						$ret = $gMailManager->sendFormMail(2, $gEnvManager->getCurrentWidgetId(), $toAddress, $fromAddress, '', '', self::SEND_PASSWORD_FORM, $mailParam);// 手動送信
+						$mailParam['URL']		= $url;		// ログイン用URL
+						$ret = $gMailManager->sendFormMail(2/*手動送信*/, $gEnvManager->getCurrentWidgetId(), $toAddress, $fromAddress, '', '', self::SEND_PASSWORD_FORM, $mailParam);// 手動送信
 						
 						// パスワード変更のメッセージ
 						$this->tmpl->addVar("send_password", "pwd_message", '新規パスワード: ' . $password);
@@ -394,254 +425,41 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 				$this->setAppErrorMsg('メール送信できません');
 			}
 			$replaceNew = true;			// 会員情報を再取得
-		} else if ($act == 'upload'){		// CSVアップロード
-			if (is_uploaded_file($_FILES['upfile']['tmp_name'])) {
-				$uploadFilename = $_FILES['upfile']['name'];		// アップロードされたファイルのファイル名取得
-				
-				// ファイルを保存するサーバディレクトリを指定
-				$tmpFile = tempnam(M3_SYSTEM_WORK_DIR_PATH, M3_SYSTEM_WORK_UPLOAD_FILENAME_HEAD);
-	
-				// アップされたテンポラリファイルを保存ディレクトリにコピー
-				$ret = move_uploaded_file($_FILES['upfile']['tmp_name'], $tmpFile);
-				if ($ret){
-					$addCount = 0;		// 追加会員数
-					$updateCount = 0;	// 更新会員数
-					$colCount = 0;		// カラム数
-					
-					// トランザクションスタート
-					$this->db->startTransaction();
-					
-					// ファイルオープン
-					$fp = fopen($tmpFile, "r");
-					
-					// データ読み込み
-					$delimType = 0;
-					if ($gEnvManager->getDefaultCsvDelimCode() == "\t") $delimType = 1;		// タブ区切り
-					while (($data = fgetByCsv($fp, $delimType)) !== false){
-						if ($colCount == 0) $colCount = count($data);		// カラム数
-
-						// ヘッダ読み飛ばし
-						if (trim($data[0]) == '会員No') continue;
-						if ($colCount != count($data)) continue;		// カラム数が合わない行も読み飛ばす
-
-						// データをDBに格納する
-						$memberNo			= trim($data[0]);			// 会員No
-						$email				= trim($data[1]);			// eメール(ログインアカウント)
-						$mobile				= '';			// 携帯電話
-						$gender				= 0;			// 性別
-						$birthday			= '';
-						if (!empty($birthday)) $birthday = $this->convertToProperDate($birthday);			// 生年月日
-						$familyName			= trim($data[2]);		// 会員名(姓)
-						$firstName			= trim($data[3]);		// 会員名(名)
-						$familyNameKana		= trim($data[4]);		// 会員名カナ(姓)
-						$firstNameKana		= trim($data[5]);		// 会員名カナ(名)
-						$zipcode			= trim($data[6]);				// 郵便番号
-						$state				= $this->db->getStateIdByName('JPN', $langId, trim($data[7]));					// 都道府県
-						$address			= trim($data[8]);			// 住所
-						$address2			= trim($data[9]);			// 住所2
-						$phone				= trim($data[10]);			// 電話番号
-						$password			= trim($data[11]);			// パスワード
-
-						// 会員Noを見て、新規登録か更新かを判断
-						$updateRecord = false;
-						if ($this->db->isExistsMemberNo($memberNo)) $updateRecord = true;
-						
-						// メールアドレスをチェック
-						if (!isMailAddress($email)){
-							$msg = 'このEメールアドレスはメールアドレス形式ではありません(' . $email . ')';
-							$this->setAppErrorMsg($msg);
-						}
-						
-						// 新規登録のときのエラーチェック
-						if (!$updateRecord){
-							if ($this->sysDb->isExistsAccount($email)){// メールアドレスがログインIDとして既に登録されているかチェック
-								$msg = 'このEメールアドレスは既に登録されています(' . $email . ')';
-								$this->setAppErrorMsg($msg);
-							}
-						}
-
-						// エラーなしの場合は、データを登録
-						if ($this->getMsgCount() == 0){
-							if ($updateRecord){			// 会員情報更新の場合
-								$changeEmail = false;		// ログインアカウントが変更かどうか
-								// 登録済み会員情報を取得
-								$ret = $this->db->getMemberByMemberNo($memberNo, $row);
-								if ($ret){
-									$serialNo = $row['sm_serial'];
-									$personId = $row['sm_person_info_id'];
-									$loginUserId = $row['sm_login_user_id'];
-									$ret = $this->db->getPersonInfo($personId, $row);
-									if ($ret){
-										$addressId = $row['pi_address_id'];
-										
-										if ($email != $row['pi_email']) $changeEmail = true;	// メールアドレス(ログインアカウント)の変更
-									}
-									// メールアドレス変更のときのエラーチェック
-									if ($changeEmail){
-										if ($this->sysDb->isExistsAccount($email)){// メールアドレスがログインIDとして既に登録されているかチェック
-											$msg = 'このEメールアドレスは既に登録されています(' . $email . ')';
-											$this->setAppErrorMsg($msg);
-										}
-									}
-									// 会員情報更新処理
-									if ($this->getMsgCount() == 0){
-										// 住所登録
-										if ($ret) $ret = $this->db->updateAddress($addressId, $langId, '', $zipcode, $state, $address, $address2, $phone, $fax, $countryId, $userId, $now, $addressId);
-
-										// 個人情報登録
-										if (empty($birthday)) $birthday = $gEnvManager->getInitValueOfTimestamp();
-										if ($ret) $ret = $this->db->updatePersonInfo($personId, $langId, $firstName, $familyName, 
-														$firstNameKana, $familyNameKana, $gender, $birthday, $email, $mobile, $addressId, $userId, $now, $personalInfoId);
-
-										// 会員情報更新
-										if ($ret){
-											$this->db->updateMember($serialNo, $langId, 1/* 個人 */, 0/* 法人情報ID */, $personalInfoId, $memberNo, $loginUserId, $userId, $now, $newSerial);
-											$updateCount++;	// 更新会員数
-										}
-
-										// パスワードが設定されているときは更新
-										if (!empty($password)){
-											// パスワード変更
-											if ($ret) $ret = $this->sysDb->updateLoginUserPassword($loginUserId, $password);
-										}
-										// メールアドレスの変更
-										if ($changeEmail){
-											if ($ret) $this->sysDb->updateLoginUserAccount($loginUserId, $email);
-										}
-									}
-								} else {		// 該当の会員が存在しないとき
-									$msg = 'この会員Noの会員が見つかりません(' . $memberNo . ')';
-									$this->setAppErrorMsg($msg);
-								}
-							} else {
-								// パスワードが空のときは自動生成
-								if (empty($password)) $password = $this->makePassword();
-				
-								// ログインユーザを作成
-								$ret = $this->db->addUser(1/* 正会員 */, $familyName . $firstName, $email, $password,
-														$gEnvManager->getCurrentWidgetId(), $userId, $now, $loginUserId);		// 新規ログインユーザIDを取得
-
-								// 住所登録
-								if ($ret) $ret = $this->db->updateAddress(0, $langId, '', $zipcode, $state, $address, $address2, $phone, $fax, $countryId, $userId, $now, $addressId);
-
-								// 個人情報登録
-								if (empty($birthday)) $birthday = $gEnvManager->getInitValueOfTimestamp();
-								if ($ret) $ret = $this->db->updatePersonInfo(0, $langId, $firstName, $familyName, $firstNameKana, $familyNameKana, 
-																				$gender, $birthday, $email, $mobile, $addressId, $userId, $now, $personalInfoId);
-
-								// 会員情報を登録
-								if ($ret){
-									$ret = $this->db->updateMember(0, $langId, 1/* 個人 */, 0/* 法人情報ID */, $personalInfoId, $memberNo, $loginUserId, $userId, $now, $newSerial);
-									$addCount++;
-								}
-							}
-						}
-					}
-					// ファイルを閉じる
-					fclose($fp);
-					
-					// トランザクション終了
-					$ret = $this->db->endTransaction();
-					if ($ret && $this->getMsgCount() == 0){
-						$this->setGuidanceMsg('データを' . $addCount . '件追加しました');
-						$this->setGuidanceMsg('データを' . $updateCount . '件更新しました');
-					} else {
-						$this->setAppErrorMsg('データ追加に失敗しました');
-					}
-				}
-				// テンポラリファイル削除
-				unlink($tmpFile);
-			} else {
-				$msg = 'アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります - ' . $gSystemManager->getMaxFileSizeForUpload() . 'バイト)';
-				$this->setAppErrorMsg($msg);
-			}
-			// 入力値初期化
-			$this->serialNo = 0;		// シリアル番号
-
-			// 入力値初期化
-			$memberNo = '';			// 会員No
-			$email = '';			// eメール(ログインアカウント)
-			$mobile = '';			// 携帯電話
-			$gender = 0;			// 性別
-			$birthday = '';			// 生年月日
-			$familyName = '';		// 会員名(姓)
-			$firstName = '';		// 会員名(名)
-			$familyNameKana = '';		// 会員名カナ(姓)
-			$firstNameKana = '';		// 会員名カナ(名)
-			$zipcode = '';				// 郵便番号
-			$this->state = 0;					// 都道府県
-			$address = '';			// 住所
-			$address2 = '';			// 住所2
-			$phone = '';			// 電話番号
-			$fax = '';				// FAX
-			$updateUser = '';	// 更新者
-			$updateDt = '';	// 更新日時
-			
-			// 会員NOのデフォルト値を自動生成
-			$memberNo = $gInstanceManager->getObject(self::EC_LIB_ID)->generateMemberNo();
-		} else if ($act == 'download'){		// CSVダウンロード
-			// ダウンロード時のデフォルトファイル名
-			$down_file = self::CSV_FILE_HEAD . date("YmdHi") . $gEnvManager->getDefaultCsvFileSuffix();
-			
-			// ヘッダ部を作成
-			$buf = array();
-			$buf[] = '会員No';
-			$buf[] = 'Eメール';
-			$buf[] = '顧客名(姓)';
-			$buf[] = '顧客名(名)';
-			$buf[] = '会員名カナ(姓)';
-			$buf[] = '会員名カナ(名)';
-			$buf[] = '郵便番号';
-			$buf[] = '都道府県';
-			$buf[] = '住所1';
-			$buf[] = '住所2';
-			$buf[] = '電話番号';
-			$buf[] = 'パスワード';
-			$delim = $gEnvManager->getDefaultCsvDelimCode();		// CSV区切りコードを取得
-			$this->csvData[] = implode($delim, $buf) . $gEnvManager->getDefaultCsvNLCode();
-		
-			// 会員リストを取得
-			$this->db->getMemberList(0, -1/*すべて取得*/, 0, array($this, 'memberCsvListLoop'));
-			
-			// CSVの出力
-			ob_end_clean();
-			header ("Content-Type: application/force-download");
-			header ("Content-Disposition: attachment; filename=" . $down_file);
-			header ("Content-Description: File Transfer");
-			header ("Content-Length: " . strlen(join("", $this->csvData)));
-			foreach ($this->csvData as $mval) {
-			    echo mb_convert_encoding($mval, 'SJIS-win');
-			    flush();
-			    ob_flush();
-			    usleep(10000);
-			}
-			ob_end_flush();
-			exit();		// スクリプト終了
 		} else {	// 初期表示
-			// 入力値初期化
-			$this->serialNo = 0;		// シリアル番号
-
-			// 入力値初期化
-			$memberNo = '';			// 会員No
-			$email = '';			// eメール(ログインアカウント)
-			$mobile = '';			// 携帯電話
-			$gender = 0;			// 性別
-			$birthday = '';			// 生年月日
-			$familyName = '';		// 会員名(姓)
-			$firstName = '';		// 会員名(名)
-			$familyNameKana = '';		// 会員名カナ(姓)
-			$firstNameKana = '';		// 会員名カナ(名)
-			$zipcode = '';				// 郵便番号
-			$this->state = 0;					// 都道府県
-			$address = '';			// 住所
-			$address2 = '';			// 住所2
-			$phone = '';			// 電話番号
-			$fax = '';				// FAX
-			$updateUser = '';	// 更新者
-			$updateDt = '';	// 更新日時
+			// 会員IDが指定されている場合は正会員情報を表示
+			$memberId = $request->trimValueOf('member');			// 会員ID
+			if (empty($memberId)){
+				if (empty($this->serialNo)){		// 新規登録のとき
+					// 入力値初期化
+					$this->memberType = 0;			// 正会員のみ新規登録可能
+					$memberNo = '';			// 会員No
+					$email = '';			// eメール(ログインアカウント)
+					$mobile = '';			// 携帯電話
+					$gender = 0;			// 性別
+					$birthday = '';			// 生年月日
+					$familyName = '';		// 会員名(姓)
+					$firstName = '';		// 会員名(名)
+					$familyNameKana = '';		// 会員名カナ(姓)
+					$firstNameKana = '';		// 会員名カナ(名)
+					$zipcode = '';				// 郵便番号
+					$this->state = 0;					// 都道府県
+					$address = '';			// 住所
+					$address2 = '';			// 住所2
+					$phone = '';			// 電話番号
+					$fax = '';				// FAX
+					$updateUser = '';	// 更新者
+					$updateDt = '';	// 更新日時
 			
-			// 会員NOのデフォルト値を自動生成
-			$memberNo = $gInstanceManager->getObject(self::EC_LIB_ID)->generateMemberNo();
+					// 会員NOのデフォルト値を自動生成
+					$memberNo = $gInstanceManager->getObject(self::EC_LIB_ID)->generateMemberNo();
+				} else {
+					$replaceNew = true;			// 会員情報を再取得
+				}
+			} else {
+				$this->serialNo = $this->db->getMemberSerialById($memberId);
+				if (!empty($this->serialNo)) $replaceNew = true;			// 会員情報を再取得
+				$this->memberType = 0;			// 正会員
+			}
 		}
 		// 会員情報を再取得
 		if ($replaceNew){
@@ -681,52 +499,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 				}
 			}
 		}
-		// 会員タイプ
-		if (empty($this->memberType)){		// 正会員のとき
-			$this->tmpl->addVar("_widget", "member_regular", 'selected');
-		} else {
-			$this->tmpl->addVar("_widget", "member_tmp", 'selected');
-		}
-		
-		// ###### 会員一覧を作成 #####
-		if (empty($this->memberType)){		// 正会員のとき
-			// 総数を取得
-			$totalCount = $this->db->getMemberCount(0);
-		} else {
-			// 総数を取得
-			$totalCount = $this->db->getMemberCount(1);
-		}
-		
-		// 表示するページ番号の修正
-		$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
-		if ($pageNo < 1) $pageNo = 1;
-		if ($pageNo > $pageCount) $pageNo = $pageCount;
-		$this->firstNo = ($pageNo -1) * $maxListCount + 1;		// 先頭番号
-		
-		if (empty($this->memberType)){		// 正会員のとき
-			// 会員リストを表示
-			$this->db->getMemberList(0, $maxListCount, ($pageNo -1) * $maxListCount, array($this, 'memberListLoop'));
-		} else {
-			// 仮会員リストを表示
-			$this->db->getMemberList(1, $maxListCount, ($pageNo -1) * $maxListCount, array($this, 'memberListLoop'));
-		}
-		
-		// ページング用リンク作成
-		$pageLink = '';
-		if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
-			for ($i = 1; $i <= $pageCount; $i++){
-				//$linkUrl = $this->currentPageUrl . '&category=' . $this->categoryId . '&page=' . $i;
-				if ($i == $pageNo){
-					$link = '&nbsp;' . $i;
-				} else {
-					//$link = '&nbsp;<a href="' . $linkUrl . '" >' . $i . '</a>';
-					$link = '&nbsp;<a href="#" onclick="selpage(\'' . $i . '\');return false;">' . $i . '</a>';
-				}
-				$pageLink .= $link;
-			}
-		}
-		$this->tmpl->addVar("_widget", "page_link", $pageLink);
-		
 		// 都道府県を設定
 		$this->db->getAllState('JPN', $langId, array($this, 'stateLoop'));
 		
@@ -777,15 +549,27 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		}
 		
 		// ボタンの設定
-		if ($this->serialNo == 0){		// 新規追加項目を選択しているとき
-			$this->tmpl->addVar("_widget", "new_selected", 'checked');// 新規追加をチェック状態にする
+		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
+			// 画面タイトル
+			$this->tmpl->addVar("_widget", "title", '正会員詳細');
 			
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
+			
+			// パスワード送信ボタンの使用制御
+			//$this->tmpl->addVar("_widget", "password_disabled", 'disabled');
+			$this->tmpl->addVar("send_password", "send_pwd", 'disabled');
 		} else {
+			// 画面タイトル
+			if (empty($this->memberType)){		// 正会員
+				$this->tmpl->addVar("_widget", "title", '正会員詳細');
+			} else {
+				$this->tmpl->addVar("_widget", "title", '仮会員詳細');
+			}
+			
 			$this->tmpl->addVar("_widget", "email_disabled", 'disabled');		// eメール(ログインアカウント)
 			
-			// パスワード送信部の表示制御
-			$this->tmpl->setAttribute('send_password', 'visibility', 'visible');
+			// パスワード送信ボタンの使用制御
+			//$this->tmpl->setAttribute('send_password', 'visibility', 'visible');
 			
 			// データ更新、削除ボタン表示
 			$this->tmpl->setAttribute('delete_button', 'visibility', 'visible');// 削除ボタン
@@ -794,9 +578,6 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 				$this->tmpl->setAttribute('update_button', 'visibility', 'visible');
 			}
 		}
-		if (empty($this->memberType)){		// 正会員のとき
-			$this->tmpl->setAttribute('csv_button', 'visibility', 'visible');		// CSVファイルアップロード、ダウンロードボタン
-		}
 		// メール送信可否状況によるボタンの制御
 		$useEmail = $this->mainDb->getConfig(self::USE_EMAIL);
 		if ($useEmail != '1'){		// メール送信不可のとき
@@ -805,12 +586,10 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		}
 		//$this->tmpl->addVar("send_password", "recreate_pwd", 'checked readonly');		// パスワード再作成は常にオン
 		
-		// 非表示項目の設定
+		// 値を埋め込む
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
-		$this->tmpl->addVar("_widget", "page", $pageNo);		// 現在のページ番号
-		
-		// パスの設定
-		$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());
+		$this->tmpl->addVar("_widget", "member_type", $this->memberType);
+		$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());	// スクリプトパスの設定
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -846,11 +625,15 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		} else if ($fetchedRow['pi_gender'] == 2){
 			$gender = '女';
 		} else {
-			$gender = '未設定';
+			$gender = '未';
 		}
+		// 都道府県名
+		$stateName = '未';
+		if (!empty($fetchedRow['gz_name'])) $stateName = $this->convertToDispString($fetchedRow['gz_name']);
 		$row = array(
-			'line_color' => $lineColor,											// 行のカラー
-			'no' => $this->firstNo + $index,									// 行番号
+			'line_color' => $lineColor,						// 行のカラー
+			'no' => $this->firstNo + $index,				// 行番号
+			'index' => $index,								// 項目番号
 			'serial' => $serial,	// シリアル番号
 			'id' => $id,			// ID
 			'member_no' => $this->convertToDispString($fetchedRow['sm_member_no']),			// 会員No
@@ -860,57 +643,14 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 			'first_name_kana' => $this->convertToDispString($fetchedRow['pi_first_name_kana']),	// 顧客名カナ(名)
 			'email' => $this->convertToDispString($fetchedRow['pi_email']),	// Eメールアドレス
 			'gender' => $gender,			// 性別
-			'state_name' => $this->convertToDispString($fetchedRow['gz_name']),	// 都道府県
+			'state_name' => $stateName,	// 都道府県
 			'selected' => $selected												// 項目選択用ラジオボタン
 		);
 		$this->tmpl->addVars('itemlist', $row);
 		$this->tmpl->parseTemplate('itemlist', 'a');
-		return true;
-	}
-	/**
-	 * 取得したデータをCSV形式で出力する
-	 *
-	 * @param int $index			行番号(0～)
-	 * @param array $fetchedRow		フェッチ取得した行
-	 * @param object $param			未使用
-	 * @return bool					true=処理続行の場合、false=処理終了の場合
-	 */
-	function memberCsvListLoop($index, $fetchedRow, $param)
-	{
-		global $gEnvManager;
 		
-		$buf = array();
-		
-		// 配列を文字列に変換
-		$delim = $gEnvManager->getDefaultCsvDelimCode();		// CSV区切りコードを取得
-		if ($delim == "\t"){// タブ区切りのCSVフォーマットのとき
-			$buf[] = $fetchedRow['sm_member_no'];		// 会員No
-			$buf[] = $fetchedRow['pi_email'];		// eメール(ログインアカウント)
-			$buf[] = $fetchedRow['pi_family_name'];		// 顧客名(姓)
-			$buf[] = $fetchedRow['pi_first_name'];		// 顧客名(名)
-			$buf[] = $fetchedRow['pi_family_name_kana'];		// 会員名カナ(姓)
-			$buf[] = $fetchedRow['pi_first_name_kana'];		// 会員名カナ(名)
-			$buf[] = $fetchedRow['ad_zipcode'];		// 郵便番号
-			$buf[] = $fetchedRow['gz_name'];		// 都道府県
-			$buf[] = $fetchedRow['ad_address1'];		// 住所
-			$buf[] = $fetchedRow['ad_address2'];		// 住所2
-			$buf[] = $fetchedRow['ad_phone'];		// 電話番号
-			$buf[] = '';		// パスワード(ダミー)
-		} else if ($delim == ","){// カンマ区切りのCSVフォーマットのとき
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['sm_member_no']);		// 会員No
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['pi_email']);		// eメール(ログインアカウント)
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['pi_family_name']);		// 顧客名(姓)
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['pi_first_name']);		// 顧客名(名)
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['pi_family_name_kana']);		// 会員名カナ(姓)
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['pi_first_name_kana']);		// 会員名カナ(名)
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['ad_zipcode']);		// 郵便番号
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['gz_name']);		// 都道府県
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['ad_address1']);		// 住所
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['ad_address2']);		// 住所2
-			$buf[] = $this->convertToEscapedCsv($fetchedRow['ad_phone']);		// 電話番号
-			$buf[] = $this->convertToEscapedCsv('');		// パスワード(ダミー)
-		}
-		$this->csvData[] = implode($delim, $buf) . $gEnvManager->getDefaultCsvNLCode();
+		// 表示中項目のシリアル番号を保存
+		$this->serialArray[] = $serial;
 		return true;
 	}
 	/**
@@ -939,5 +679,35 @@ class admin_ec_mainMemberWidgetContainer extends admin_ec_mainBaseWidgetContaine
 		$this->tmpl->parseTemplate('state_list', 'a');
 		return true;
 	}
+	
+	/**
+	 * ユーザの削除、ログインアカウントも削除
+	 *
+	 * @param int $serial		シリアル番号
+	 * @return bool				true=成功、false=失敗
+	 */
+	function deleteUser($serial)
+	{
+		$loginUserId = '';
+		
+		// ログインユーザIDを取得
+		if (empty($this->memberType)){		// 正会員のとき
+			if ($this->db->getMemberBySerial(0, $serial, $row)) $loginUserId = $row['sm_login_user_id'];
+		} else {
+			if ($this->db->getMemberBySerial(1, $serial, $row)) $loginUserId = $row['sb_login_user_id'];
+		}
+		if (empty($this->memberType)){		// 正会員のとき
+			$ret = $this->db->delMemberBySerial(0, $serial);
+		} else {
+			$ret = $this->db->delMemberBySerial(1, $serial);
+		}
+		if ($ret) $this->sysDb->delLoginUser($loginUserId);
+
+		if ($ret){		// データ削除成功のとき
+			return true;
+		} else {
+			return false;
+		}
+	}
 }
 ?>
