@@ -30,11 +30,13 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	private $billState;		// 請求都道府県
 	private $deliveryMethod;		// 配送方法
 	private $payMethod;			// 支払い方法
+	private $search_status;		// 検索ステータス
 	private $serialArray = array();			// シリアル番号の配列
 	const STANDARD_PRICE = 'selling';		// 通常価格
-	const ORDER_STATUS_CLOSE = 500;			// 受注処理終了
+	const ORDER_STATUS_CLOSE = 900;			// 受注処理終了
 	const PRICE_OBJ_ID = "eclib";		// 価格計算オブジェクトID
 	const DEFAULT_COUNTRY_ID = 'JPN';	// デフォルト国ID
+	const DEFAULT_LIST_COUNT = 20;			// 最大リスト表示数
 	
 	/**
 	 * コンストラクタ
@@ -65,7 +67,12 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function _setTemplate($request, &$param)
 	{
-		return 'admin_order.tmpl.html';
+		$task = $request->trimValueOf('task');
+		if ($task == 'order_detail'){		// 詳細画面
+			return 'admin_order_detail.tmpl.html';
+		} else {
+			return 'admin_order.tmpl.html';
+		}
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -77,19 +84,136 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 * @param								なし
 	 */
 	function _assign($request, &$param)
+	{
+		$task = $request->trimValueOf('task');
+		if ($task == 'order_detail'){		// 詳細画面
+			return $this->createDetail($request);
+		} else {			// 一覧画面
+			return $this->createList($request);
+		}
+	}
+	/**
+	 * 一覧画面作成
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param								なし
+	 */
+	function createList($request)
+	{
+		global $gEnvManager;
+
+		// ユーザ情報、表示言語
+		$this->langId = $gEnvManager->getDefaultLanguage();		// デフォルト言語
+		$this->userId = $gEnvManager->getCurrentUserId();
+		
+		// ##### 検索条件 #####
+		$pageNo = $request->trimValueOf('page');				// ページ番号
+		if (empty($pageNo)) $pageNo = 1;
+		// DBの保存設定値を取得
+		$maxListCount = self::DEFAULT_LIST_COUNT;				// 表示項目数
+		$this->search_status = $request->trimValueOf('status');		// ステータス
+		$keyword = $request->trimValueOf('keyword');			// 検索キーワード
+		
+		$act = $request->trimValueOf('act');
+		if ($act == 'search'){		// 検索のとき
+			$pageNo = 1;		// ページ番号初期化
+		} else if ($act == 'delete'){		// 項目削除の場合
+			$listedItem = explode(',', $request->trimValueOf('seriallist'));
+			$delItems = array();
+			for ($i = 0; $i < count($listedItem); $i++){
+				// 項目がチェックされているかを取得
+				$itemName = 'item' . $i . '_selected';
+				$itemValue = ($request->trimValueOf($itemName) == 'on') ? 1 : 0;
+				
+				if ($itemValue){		// チェック項目
+					$delItems[] = $listedItem[$i];
+				}
+			}
+			if (count($delItems) > 0){
+				for ($i = 0; $i < count($delItems); $i++){
+					$ret = $this->db->delOrder($delItems[$i], $this->userId);
+					if (!$ret) break;
+				}
+				if ($ret){		// データ削除成功のとき
+					$this->setGuidanceMsg('データを削除しました');
+				} else {
+					$this->setAppErrorMsg('データ削除に失敗しました');
+				}
+			}
+		}
+		
+		// ###### 検索条件を作成 ######
+		// ステータス
+		if ($this->search_status == 0){		// 終了、キャンセル以外
+			$statusMin = 0;
+			$statusMax = self::ORDER_STATUS_CLOSE -1;
+		} else {
+			$statusMin = 0;
+			$statusMax = 0;
+		}
+		
+		// 総数を取得
+		$totalCount = $this->db->searchOrderHeaderCount($statusMin, $statusMax);
+		$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
+
+		// 表示するページ番号の修正
+		if ($pageNo < 1) $pageNo = 1;
+		if ($pageNo > $pageCount) $pageNo = $pageCount;
+
+		// 商品リストを表示
+		$this->db->searchOrderHeader($statusMin, $statusMax, $maxListCount, ($pageNo -1) * $maxListCount, array($this, 'orderListLoop'));
+
+		// ページング用リンク作成
+		$pageLink = '';
+		if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
+			for ($i = 1; $i <= $pageCount; $i++){
+				$linkUrl = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=order&status=' . $this->search_status . '&page=' . $i;
+				if ($i == $pageNo){
+					$link = '&nbsp;' . $i;
+				} else {
+					$link = '&nbsp;<a href="' . $linkUrl . '" >' . $i . '</a>';
+				}
+				$pageLink .= $link;
+			}
+		}
+		// 検出順を作成
+		$startNo = ($pageNo -1) * $maxListCount +1;
+		$endNo = $pageNo * $maxListCount > $totalCount ? $totalCount : $pageNo * $maxListCount;
+		$this->tmpl->addVar("_widget", "page_link", $pageLink);
+		$this->tmpl->addVar("_widget", "total_count", $totalCount);
+		$this->tmpl->addVar("search_range", "start_no", $startNo);
+		$this->tmpl->addVar("search_range", "end_no", $endNo);
+		if ($totalCount > 0) $this->tmpl->setAttribute('search_range', 'visibility', 'visible');// 検出範囲を表示
+		
+		if ($this->search_status == 0){		// 終了、キャンセル以外
+			$this->tmpl->addVar("_widget", "status_active_selected", 'selected');
+		} else {
+			$this->tmpl->addVar("_widget", "status_all_selected", 'selected');
+		}
+		
+		// 埋め込みパラメータの設定
+		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示中の項目のシリアル番号設定
+		$this->tmpl->addVar("_widget", "admin_url", $gEnvManager->getDefaultAdminUrl());
+		$this->tmpl->addVar('_widget', 'widget_id', $gEnvManager->getCurrentWidgetId());
+	}
+	/**
+	 * 詳細画面作成
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param								なし
+	 */
+	function createDetail($request)
 	{
 		global $gEnvManager;
 
 		// ユーザ情報、表示言語
 		$this->now = date("Y/m/d H:i:s");	// 現在日時
-		$defaultLang	= $gEnvManager->getDefaultLanguage();
-		$defaultLangName = $gEnvManager->getDefaultLanguageNameByCurrentLanguage();// デフォルト言語の現在の表示名を取得
-		$this->langId = $defaultLang;		// デフォルト言語
+		$this->langId = $gEnvManager->getDefaultLanguage();		// デフォルト言語
 		$this->userId = $gEnvManager->getCurrentUserId();
 		
 		$act = $request->trimValueOf('act');
 		$this->serialNo = $request->trimValueOf('serial');			// 選択項目のシリアル番号
-		if (empty($this->serialNo)) $this->serialNo = 0;
 				
 		// 入力項目
 		$name = $request->trimValueOf('item_name');		// 顧客名
@@ -122,90 +246,8 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 
 		$this->orderStatus = $request->trimValueOf('item_order_status');		// 受注ステータス
 		
-		if ($act == 'select'){		// 項目選択の場合
-			if ($this->serialNo == 0){		// シリアル番号が0のときは、新規追加モードにする
-				$name = '';		// 顧客名
-				$nameKana = '';		// 顧客名(カナ)
-				$custm_zipcode = '';		// 顧客郵便番号
-				$custm_address = '';		// 顧客住所
-				$custm_address2 = '';		// 顧客住所2
-				$custm_phone = '';		// 顧客電話番号
-				$custm_fax = '';		// 顧客FAX
-				$deliv_name = '';		// 配送先名
-				$deliv_name_kana = '';		// 配送先名(カナ)
-				$deliv_zipcode = '';		// 配送先郵便番号
-				$deliv_address = '';		// 配送先住所
-				$deliv_address2 = '';		// 配送先住所2
-				$deliv_phone = '';		// 配送先電話番号
-				$deliv_fax = '';		// 配送先FAX
-				$bill_name = '';		// 請求先名
-				$bill_name_kana = '';		// 請求先名(カナ)
-				$bill_zipcode = '';		// 請求先郵便番号
-				$bill_address = '';		// 請求先住所
-				$bill_address2 = '';		// 請求先住所2
-				$bill_phone = '';		// 請求先電話番号
-				$bill_fax = '';		// 請求先FAX
-				$this->deliveryMethod = '';		// 選択中の配送方法
-				$this->payMethod = '';			// 選択中の支払い方法
-				$this->custmState = 0;		// 顧客都道府県
-				$this->delivState = 0;		// 配送都道府県
-				$this->billState = 0;		// 請求都道府県
-				$this->orderStatus = 0;		// 受注ステータス
-			} else {
-				// データ再取得
-				$ret = $this->db->getOrderBySerial($this->serialNo, $row);
-				if ($ret){
-					// 取得値を設定
-					$this->langId = $row['or_language_id'];		// 受注時の言語
-					$orderNo = $row['or_order_no'];		// 受注番号
-					
-					// ログインユーザ情報を取得
-					$ret = $this->db->getLoginUserById($row['or_user_id'], $loginUserRow);
-					if ($ret) $email = $loginUserRow['lu_account'];
-					
-					$name = $row['or_custm_name'];		// 顧客名
-					$nameKana = $row['or_custm_name_kana'];		// 顧客名(カナ)
-					$custm_zipcode = $row['or_custm_zipcode'];		// 顧客郵便番号
-					$custm_address = $row['or_custm_address1'];		// 顧客住所
-					$custm_address2 = $row['or_custm_address2'];		// 顧客住所2
-					$custm_phone = $row['or_custm_phone'];		// 顧客電話番号
-					$custm_fax = $row['or_custm_fax'];		// 顧客FAX
-					
-					$deliv_name = $row['or_deliv_name'];		// 配送先名
-					$deliv_name_kana = $row['or_deliv_name_kana'];		// 配送先名(カナ)
-					$deliv_zipcode = $row['or_deliv_zipcode'];		// 配送先郵便番号
-					$deliv_address = $row['or_deliv_address1'];		// 配送先住所
-					$deliv_address2 = $row['or_deliv_address2'];		// 配送先住所2
-					$deliv_phone = $row['or_deliv_phone'];		// 配送先電話番号
-					$deliv_fax = $row['or_deliv_fax'];		// 配送先FAX
-					$bill_name = $row['or_bill_name'];		// 請求先名
-					$bill_name_kana = $row['or_bill_name_kana'];		// 請求先名(カナ)
-					$bill_zipcode = $row['or_bill_zipcode'];		// 請求先郵便番号
-					$bill_address = $row['or_bill_address1'];		// 請求先住所
-					$bill_address2 = $row['or_bill_address2'];		// 請求先住所2
-					$bill_phone = $row['or_bill_phone'];		// 請求先電話番号
-					$bill_fax = $row['or_bill_fax'];		// 請求先FAX
-					$this->deliveryMethod = $row['or_deliv_method_id'];		// 選択中の配送方法
-					$this->payMethod = $row['or_pay_method_id'];			// 選択中の支払い方法
-					$this->custmState = $row['or_custm_state_id'];		// 顧客都道府県
-					$this->delivState = $row['or_deliv_state_id'];		// 配送都道府県
-					$this->billState = $row['or_bill_state_id'];		// 請求都道府県
-	
-					$this->orderStatus = $row['or_order_status'];		// 受注ステータス
-					$this->currency	= $row['or_currency_id'];	// 通貨
-					$subtotal = $row['or_subtotal'];		// 商品総額
-					$delivFee = $row['or_deliv_fee'];		// 配送料
-					$charge = $row['or_charge'];		// 手数料
-					$total = $row['or_total'];		// 総額
-					
-					$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
-					$updateDt = $this->convertToDispDateTime($row['or_create_dt']);	// 更新日時
-					
-					// 受注商品を取得
-					$this->db->getOrderDetailList($row['or_id'], array($this, 'orderItemLoop'));
-				}
-			}
-		} else if ($act == 'update'){		// 項目更新の場合
+		$replaceNew = false;		// データを再取得するかどうか
+		if ($act == 'update'){		// 項目更新の場合
 			// 入力チェック
 			$this->checkInput($name,				'顧客名');		
 			$this->checkInput($nameKana,			'顧客名(カナ)');
@@ -254,67 +296,12 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 						
 					// トランザクション終了
 					$ret = $this->db->endTransaction();
-				
 					if ($ret){
 						$this->setGuidanceMsg('データを更新しました');
 					
-						// 登録済みのカテゴリーを取得
+						// 登録済みの受注情報を再取得
 						$this->serialNo = $newSerial;
-
-						// データ再取得
-						$ret = $this->db->getOrderBySerial($this->serialNo, $row);
-						if ($ret){
-							// 取得値を設定
-							$this->langId = $row['or_language_id'];		// 受注時の言語
-							$orderNo = $row['or_order_no'];		// 受注番号
-					
-							// ログインユーザ情報を取得
-							$ret = $this->db->getLoginUserById($row['or_user_id'], $loginUserRow);
-							if ($ret) $email = $loginUserRow['lu_account'];
-					
-							$name = $row['or_custm_name'];		// 顧客名
-							$nameKana = $row['or_custm_name_kana'];		// 顧客名(カナ)
-							$custm_zipcode = $row['or_custm_zipcode'];		// 顧客郵便番号
-							$custm_address = $row['or_custm_address1'];		// 顧客住所
-							$custm_address2 = $row['or_custm_address2'];		// 顧客住所2
-							$custm_phone = $row['or_custm_phone'];		// 顧客電話番号
-							$custm_fax = $row['or_custm_fax'];		// 顧客FAX
-					
-							$deliv_name = $row['or_deliv_name'];		// 配送先名
-							$deliv_name_kana = $row['or_deliv_name_kana'];		// 配送先名(カナ)
-							$deliv_zipcode = $row['or_deliv_zipcode'];		// 配送先郵便番号
-							$deliv_address = $row['or_deliv_address1'];		// 配送先住所
-							$deliv_address2 = $row['or_deliv_address2'];		// 配送先住所2
-							$deliv_phone = $row['or_deliv_phone'];		// 配送先電話番号
-							$deliv_fax = $row['or_deliv_fax'];		// 配送先FAX
-							$bill_name = $row['or_bill_name'];		// 請求先名
-							$bill_name_kana = $row['or_bill_name_kana'];		// 請求先名(カナ)
-							$bill_zipcode = $row['or_bill_zipcode'];		// 請求先郵便番号
-							$bill_address = $row['or_bill_address1'];		// 請求先住所
-							$bill_address2 = $row['or_bill_address2'];		// 請求先住所2
-							$bill_phone = $row['or_bill_phone'];		// 請求先電話番号
-							$bill_fax = $row['or_bill_fax'];		// 請求先FAX
-							$this->deliveryMethod = $row['or_deliv_method_id'];		// 選択中の配送方法
-							$this->payMethod = $row['or_pay_method_id'];			// 選択中の支払い方法
-							$this->custmState = $row['or_custm_state_id'];		// 顧客都道府県
-							$this->delivState = $row['or_deliv_state_id'];		// 配送都道府県
-							$this->billState = $row['or_bill_state_id'];		// 請求都道府県
-	
-							$this->orderStatus = $row['or_order_status'];		// 受注ステータス
-							$this->currency	= $row['or_currency_id'];	// 通貨
-							$subtotal = $row['or_subtotal'];		// 商品総額
-							$delivFee = $row['or_deliv_fee'];		// 配送料
-							$charge = $row['or_charge'];		// 手数料
-							$total = $row['or_total'];		// 総額
-					
-							$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
-							$updateDt = $this->convertToDispDateTime($row['or_create_dt']);	// 更新日時
-					
-							// 受注商品を取得
-							$this->db->getOrderDetailList($row['or_id'], array($this, 'orderItemLoop'));
-						}
-					} else {
-						$this->setAppErrorMsg('データ更新に失敗しました');
+						$replaceNew = true;
 					}
 				}
 			}
@@ -332,43 +319,96 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				}
 			}
 		} else {	// 初期表示
-			// 入力値初期化
-			$name = '';		// 顧客名
-			$nameKana = '';		// 顧客名(カナ)
-			$custm_zipcode = '';		// 顧客郵便番号
-			$custm_address = '';		// 顧客住所
-			$custm_address2 = '';		// 顧客住所2
-			$custm_phone = '';		// 顧客電話番号
-			$custm_fax = '';		// 顧客FAX
-			$deliv_name = '';		// 配送先名
-			$deliv_name_kana = '';		// 配送先名(カナ)
-			$deliv_zipcode = '';		// 配送先郵便番号
-			$deliv_address = '';		// 配送先住所
-			$deliv_address2 = '';		// 配送先住所2
-			$deliv_phone = '';		// 配送先電話番号
-			$deliv_fax = '';		// 配送先FAX
-			$bill_name = '';		// 請求先名
-			$bill_name_kana = '';		// 請求先名(カナ)
-			$bill_zipcode = '';		// 請求先郵便番号
-			$bill_address = '';		// 請求先住所
-			$bill_address2 = '';		// 請求先住所2
-			$bill_phone = '';		// 請求先電話番号
-			$bill_fax = '';		// 請求先FAX
-			$this->deliveryMethod = '';		// 選択中の配送方法
-			$this->payMethod = '';			// 選択中の支払い方法
-			$this->custmState = 0;		// 顧客都道府県
-			$this->delivState = 0;		// 配送都道府県
-			$this->billState = 0;		// 請求都道府県
-			$this->orderStatus = 0;		// 受注ステータス
+			if (empty($this->serialNo)){		// 新規登録のとき
+				// 入力値初期化
+				$name = '';		// 顧客名
+				$nameKana = '';		// 顧客名(カナ)
+				$custm_zipcode = '';		// 顧客郵便番号
+				$custm_address = '';		// 顧客住所
+				$custm_address2 = '';		// 顧客住所2
+				$custm_phone = '';		// 顧客電話番号
+				$custm_fax = '';		// 顧客FAX
+				$deliv_name = '';		// 配送先名
+				$deliv_name_kana = '';		// 配送先名(カナ)
+				$deliv_zipcode = '';		// 配送先郵便番号
+				$deliv_address = '';		// 配送先住所
+				$deliv_address2 = '';		// 配送先住所2
+				$deliv_phone = '';		// 配送先電話番号
+				$deliv_fax = '';		// 配送先FAX
+				$bill_name = '';		// 請求先名
+				$bill_name_kana = '';		// 請求先名(カナ)
+				$bill_zipcode = '';		// 請求先郵便番号
+				$bill_address = '';		// 請求先住所
+				$bill_address2 = '';		// 請求先住所2
+				$bill_phone = '';		// 請求先電話番号
+				$bill_fax = '';		// 請求先FAX
+				$this->deliveryMethod = '';		// 選択中の配送方法
+				$this->payMethod = '';			// 選択中の支払い方法
+				$this->custmState = 0;		// 顧客都道府県
+				$this->delivState = 0;		// 配送都道府県
+				$this->billState = 0;		// 請求都道府県
+				$this->orderStatus = 0;		// 受注ステータス
+			} else {
+				$replaceNew = true;		// データ取得
+			}
+		}
+		if ($replaceNew){
+			// データ再取得
+			$ret = $this->db->getOrderBySerial($this->serialNo, $row);
+			if ($ret){
+				// 取得値を設定
+				$this->langId = $row['or_language_id'];		// 受注時の言語
+				$orderNo = $row['or_order_no'];		// 受注番号
+				
+				// ログインユーザ情報を取得
+				$ret = $this->db->getLoginUserById($row['or_user_id'], $loginUserRow);
+				if ($ret) $email = $loginUserRow['lu_account'];
+				
+				$name = $row['or_custm_name'];		// 顧客名
+				$nameKana = $row['or_custm_name_kana'];		// 顧客名(カナ)
+				$custm_zipcode = $row['or_custm_zipcode'];		// 顧客郵便番号
+				$custm_address = $row['or_custm_address1'];		// 顧客住所
+				$custm_address2 = $row['or_custm_address2'];		// 顧客住所2
+				$custm_phone = $row['or_custm_phone'];		// 顧客電話番号
+				$custm_fax = $row['or_custm_fax'];		// 顧客FAX
+				
+				$deliv_name = $row['or_deliv_name'];		// 配送先名
+				$deliv_name_kana = $row['or_deliv_name_kana'];		// 配送先名(カナ)
+				$deliv_zipcode = $row['or_deliv_zipcode'];		// 配送先郵便番号
+				$deliv_address = $row['or_deliv_address1'];		// 配送先住所
+				$deliv_address2 = $row['or_deliv_address2'];		// 配送先住所2
+				$deliv_phone = $row['or_deliv_phone'];		// 配送先電話番号
+				$deliv_fax = $row['or_deliv_fax'];		// 配送先FAX
+				$bill_name = $row['or_bill_name'];		// 請求先名
+				$bill_name_kana = $row['or_bill_name_kana'];		// 請求先名(カナ)
+				$bill_zipcode = $row['or_bill_zipcode'];		// 請求先郵便番号
+				$bill_address = $row['or_bill_address1'];		// 請求先住所
+				$bill_address2 = $row['or_bill_address2'];		// 請求先住所2
+				$bill_phone = $row['or_bill_phone'];		// 請求先電話番号
+				$bill_fax = $row['or_bill_fax'];		// 請求先FAX
+				$this->deliveryMethod = $row['or_deliv_method_id'];		// 選択中の配送方法
+				$this->payMethod = $row['or_pay_method_id'];			// 選択中の支払い方法
+				$this->custmState = $row['or_custm_state_id'];		// 顧客都道府県
+				$this->delivState = $row['or_deliv_state_id'];		// 配送都道府県
+				$this->billState = $row['or_bill_state_id'];		// 請求都道府県
+
+				$this->orderStatus = $row['or_order_status'];		// 受注ステータス
+				$this->currency	= $row['or_currency_id'];	// 通貨
+				$subtotal = $row['or_subtotal'];		// 商品総額
+				$delivFee = $row['or_deliv_fee'];		// 配送料
+				$charge = $row['or_charge'];		// 手数料
+				$total = $row['or_total'];		// 総額
+				
+				$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
+				$updateDt = $this->convertToDispDateTime($row['or_create_dt']);	// 更新日時
+				
+				// 受注商品を取得
+				$this->db->getOrderDetailList($row['or_id'], array($this, 'orderItemLoop'));
+			}
 		}
 		
-		// #### 受注状況リストを作成 ####
-		// レコード削除されていないもの、終了していないものを取得
-		$this->db->getOrderHeaderByStatus(array($this, 'orderListLoop'), 0, self::ORDER_STATUS_CLOSE -1);
-		
 		// 選択中の受注IDを設定
-		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
-		if ($this->serialNo == 0){		// シリアル番号が0のときは新規とする
+		if (empty($this->serialNo)){		// シリアル番号が空のときは新規とする
 			$this->tmpl->addVar("_widget", "order_no", '新規');
 			
 			$this->tmpl->addVar("_widget", "new_selected", 'checked');// 新規追加をチェック状態にする
@@ -431,40 +471,20 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$this->db->getAllPaymentMethod($this->langId, array($this, 'paymentMethodLoop'));
 			
 		// ボタンの設定
-		if ($this->serialNo == 0){		// 新規追加項目を選択しているとき
+		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
+			$this->tmpl->setAttribute('add_button1', 'visibility', 'visible');// 「新規追加」ボタン
+			$this->tmpl->setAttribute('add_button2', 'visibility', 'visible');// 「新規追加」ボタン
 		} else {
 			// データ更新、削除ボタン表示
-			$this->tmpl->setAttribute('delete_button', 'visibility', 'visible');// 削除ボタン
 			$this->tmpl->setAttribute('update_button', 'visibility', 'visible');
+			$this->tmpl->setAttribute('update_button1', 'visibility', 'visible');
+			$this->tmpl->setAttribute('update_button2', 'visibility', 'visible');
 		}
-					
-		// 非表示項目の設定
+		// 埋め込みパラメータの設定
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
-
-		// 表示中の項目のを設定
-		$serialList = '';
-		if (!empty($this->serialArray)) $serialList = implode($this->serialArray, ',');
-		$this->tmpl->addVar("_widget", "serial_list", $serialList);
-		
-		// パスの設定
-		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
-		$this->tmpl->addVar("_widget", "widget_sc_url", $gEnvManager->getCurrentWidgetScriptsUrl());
-		$this->tmpl->addVar("_widget", "image_path", $gEnvManager->getRootUrl() . '/resource/');		// 画像の格納場所
-		
-		/*
-		// メニューを作成
-		$menuText = '<table width="100%">';
-		$menuText .= '<tr><td><input type="button" class="button" onClick="goTask(\'category\');" value="カテゴリー登録">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'product\');" value="商品管理">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'order\');" value="受注管理">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'member\');" value="会員管理">' . M3_NL;
-		$menuText .= '<input type="button" class="button" onClick="goTask(\'shopinfo\');" value="基本設定">' . M3_NL;
-		$menuText .= '</td></tr>' . M3_NL;
-		$menuText .= '</table>' . M3_NL;
-		$menuText .= '<br>' . M3_NL;
-		$this->tmpl->addVar("_widget", "menu_items", $menuText);
-		*/
+		$this->tmpl->addVar("_widget", "admin_url", $gEnvManager->getDefaultAdminUrl());
+		$this->tmpl->addVar('_widget', 'widget_id', $gEnvManager->getCurrentWidgetId());
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -494,8 +514,15 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$this->ecObj->getPriceWithoutTax($fetchedRow['or_total'], $dispPrice);		// 表示文字列作成
 		
 		// 受注ステータス
-		$ret = $this->db->getOrderStatusName($fetchedRow['or_order_status'], $this->langId, $row);
-		if ($ret) $status = $row['os_name'];
+		$orderStatus = $fetchedRow['or_order_status'];
+		$ret = $this->db->getOrderStatusName($orderStatus, $this->langId, $row);
+		if ($ret){
+			if ($orderStatus < 400){
+				$status = '<font color="red">' . $row['os_name'] . '</font>';		
+			} else {// 配送済み、終了、キャンセル
+				$status = '<font color="green">' . $row['os_name'] . '</font>';
+			}
+		}
 			
 		// 配送日時
 		$delibDt = '';
@@ -503,9 +530,9 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		
 		$row = array(
 			'line_color' => $lineColor,											// 行のカラー
-			'no' => $index + 1,													// 行番号
+			'index' => $index,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['or_serial']),	// シリアル番号
-			'id' => $id,			// ID
+			'id' => $fetchedRow['or_custm_id'],			// 顧客ID
 			'order_no' => $this->convertToDispString($fetchedRow['or_order_no']),		// 受注番号
 			'name' => $this->convertToDispString($fetchedRow['or_custm_name']),		// 顧客名
 			'total' => $dispPrice,		// 購入額
@@ -514,7 +541,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 			'regist_dt' => $this->convertToDispDateTime($fetchedRow['or_regist_dt']),	// 受付日時
 			'deliv_dt' => $delibDt,	// 配送日時
 			//'update_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 更新者
-			//'update_dt' => $this->convertToDispDateTime($fetchedRow['pt_create_dt']),	// 更新日時
+			'update_dt' => $this->convertToDispDateTime($fetchedRow['or_create_dt']),	// 更新日時
 			'default' => $default,											// デフォルト項目
 			'selected' => $selected												// 項目選択用ラジオボタン
 		);
