@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -22,7 +22,9 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 	private $sysDb;		// システムDBオブジェクト
 	private $langId;		// 表示言語
 	private $iWidgetId;	// インナーウィジェットID
-	const IWIDGET_TYPE = 'PAYMENT';		// 配送方法用インナーウィジェット
+	private $serialNo;		// 選択中の項目のシリアル番号
+	private $serialArray = array();		// 表示されている項目シリアル番号
+	const IWIDGET_TYPE = 'PAYMENT';		// 支払方法用インナーウィジェット
 	
 	/**
 	 * コンストラクタ
@@ -50,7 +52,12 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 	 */
 	function _setTemplate($request, &$param)
 	{
-		return 'admin_paymethod.tmpl.html';
+		$task = $request->trimValueOf('task');
+		if ($task == 'paymethod_detail'){		// 詳細画面
+			return 'admin_paymethod_detail.tmpl.html';
+		} else {			// 一覧画面
+			return 'admin_paymethod.tmpl.html';
+		}
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -62,14 +69,67 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 	 * @param								なし
 	 */
 	function _assign($request, &$param)
+	{
+		$task = $request->trimValueOf('task');
+		if ($task == 'paymethod_detail'){	// 詳細画面
+			return $this->createDetail($request);
+		} else {			// 一覧画面
+			return $this->createList($request);
+		}
+	}
+	/**
+	 * 一覧画面作成
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param								なし
+	 */
+	function createList($request)
 	{
 		global $gEnvManager;
-		global $gPageManager;
 		
-		$isRegistered = false;		// 登録更新完了したかどうか
 		$this->langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
 		$act = $request->trimValueOf('act');
 		
+		if ($act == 'delete'){		// 項目削除の場合
+			$listedItem = explode(',', $request->trimValueOf('seriallist'));
+			$delItems = array();
+			for ($i = 0; $i < count($listedItem); $i++){
+				// 項目がチェックされているかを取得
+				$itemName = 'item' . $i . '_selected';
+				$itemValue = ($request->trimValueOf($itemName) == 'on') ? 1 : 0;
+				
+				if ($itemValue){		// チェック項目
+					$delItems[] = $listedItem[$i];
+				}
+			}
+			if (count($delItems) > 0){
+				$ret = $this->db->deletePayMethodDefBySerial($delItems);
+				if ($ret){		// データ削除成功のとき
+					$this->setGuidanceMsg('データを削除しました');
+				} else {
+					$this->setAppErrorMsg('データ削除に失敗しました');
+				}
+			}
+		}
+		// 一覧を表示
+		$this->db->getAllPayMethodDef($this->langId, 0/*デフォルトのセットID*/, array($this, 'payDefLoop'));
+		
+		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
+	}
+	/**
+	 * 詳細画面作成
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param								なし
+	 */
+	function createDetail($request)
+	{
+		global $gEnvManager;
+		
+		$this->langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
+		$act = $request->trimValueOf('act');
+		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
+		
 		$this->id	= $request->trimValueOf('id');	// ID
 		$addid	= $request->trimValueOf('item_id');	// ID
 		$name	= $request->trimValueOf('item_name');	// 名前
@@ -80,43 +140,7 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 		$param = '';			// インナーウィジェット用パラメータ
 		
 		$replaceNew = false;		// データを再取得するかどうか
-		if ($act == 'select'){		// 行選択のとき
-			if (empty($this->id)){		// 新規追加モードにする
-				$addid		= '';	// ID
-				$name	= '';	// 名前
-				$desc	= '';	// 説明
-				$index	= $this->db->getMaxPayMethodIndex($this->langId, 0/*デフォルトのセットID*/) + 1;	// 表示順
-				$visible	= 1;	// 表示状態
-				$this->iWidgetId	= '';	// インナーウィジェットID
-			} else {
-				$replaceNew = true;		// 設定データを取得
-			}
-		} else if ($act == 'selectcalc'){		// 計算方法選択のとき
-
-		} else if ($act == 'update'){		// 行更新のとき
-			// 入力チェック
-			$this->checkInput($name, '表示名');
-			$this->checkNumeric($index, '表示順');
-			
-			// インナーウィジェット更新
-			if ($this->getMsgCount() == 0){
-				if (!empty($this->iWidgetId)){
-					// インナーウィジェットでのパラメータの更新に成功した場合
-					$this->updateIWidgetParam($this->iWidgetId, $this->id, $param, $optionParam, true);
-				}
-			}
-			
-			// エラーなしの場合は、データを更新
-			if ($this->getMsgCount() == 0){
-				$ret = $this->db->updatePayMethodDef($this->id, $this->langId, 0/*デフォルトのセットID*/, $name, $desc, $index, $visible, $this->iWidgetId, $param);
-				if ($ret){		// 更新成功のとき
-					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
-					$replaceNew = true;			// データを再取得
-				} else {
-					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
-				}
-			}
-		} else if ($act == 'add'){		// 新規追加のとき
+		if ($act == 'add'){		// 新規追加のとき
 			// 入力チェック
 			$this->checkSingleByte($addid, 'ID');
 			$this->checkInput($name, '表示名');
@@ -145,21 +169,52 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 					$this->setMsg(self::MSG_APP_ERR, 'データ追加に失敗しました');
 				}
 			}
+		} else if ($act == 'update'){		// 行更新のとき
+			// 入力チェック
+			$this->checkInput($name, '表示名');
+			$this->checkNumeric($index, '表示順');
+			
+			// インナーウィジェット更新
+			if ($this->getMsgCount() == 0){
+				if (!empty($this->iWidgetId)){
+					// インナーウィジェットでのパラメータの更新に成功した場合
+					$this->updateIWidgetParam($this->iWidgetId, $this->id, $param, $optionParam, true);
+				}
+			}
+			
+			// エラーなしの場合は、データを更新
+			if ($this->getMsgCount() == 0){
+				$ret = $this->db->updatePayMethodDef($this->id, $this->langId, 0/*デフォルトのセットID*/, $name, $desc, $index, $visible, $this->iWidgetId, $param);
+				if ($ret){		// 更新成功のとき
+					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
+					$replaceNew = true;			// データを再取得
+				} else {
+					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
+				}
+			}
 		} else if ($act == 'delete'){		// 削除のとき
-			$ret = $this->db->deletePayMethodDef($this->id, $this->langId, 0/*デフォルトのセットID*/);
+			$ret = $this->db->deletePayMethodDefBySerial(array($this->serialNo));
 			if ($ret){		// データ更新成功のとき
 				$this->setMsg(self::MSG_GUIDANCE, '項目を削除しました');
 			} else {
 				$this->setMsg(self::MSG_APP_ERR, '項目削除に失敗しました');
 			}
+		} else if ($act == 'selectcalc'){		// 計算方法選択のとき
 		} else {		// 初期状態
-			$this->id = '';			// 選択中の配送項目ID
-			$addid		= '';	// ID
-			$name	= '';	// 名前
-			$desc	= '';	// 説明
-			$index	= $this->db->getMaxPayMethodIndex($this->langId, 0/*デフォルトのセットID*/) + 1;	// 表示順
-			$visible	= 1;	// 表示状態
-			$this->iWidgetId	= '';	// インナーウィジェットID
+			// シリアル番号からIDを取得
+			$this->id = $this->db->getPayMethodDefIdBySerial($this->serialNo);			// 選択中の項目ID
+			if (empty($this->id)){	// 空のときは新規とする
+				$this->serialNo = 0;
+				
+				$addid		= '';	// ID
+				$name	= '';	// 名前
+				$desc	= '';	// 説明
+				$index	= $this->db->getMaxPayMethodIndex($this->langId, 0/*デフォルトのセットID*/) + 1;	// 表示順
+				$visible	= 1;	// 表示状態
+				$this->iWidgetId	= '';	// インナーウィジェットID
+			} else {
+				$replaceNew = true;			// データを再取得
+			}
 		}
 		// データを再取得のとき
 		if ($replaceNew){
@@ -171,15 +226,14 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 				$index		= $row['po_index'];	// 表示順
 				$visible	= $row['po_visible'];	// 表示状態
 				$this->iWidgetId	= $row['po_iwidget_id'];	// インナーウィジェットID
-				
 				if (!empty($this->iWidgetId)){
 					// パラメータをインナーウィジェットに設定
 					$this->setIWidgetParam($this->iWidgetId, $this->id, $row['po_param'], $optionParam, true);
 				}
 			}
 		}
-
-		if (empty($this->id)){		// IDが空のときは新規とする
+		
+		if (empty($this->serialNo)){		// シリアル番号が空のときは新規とする
 			$this->tmpl->addVar("_widget", "id_label", '新規');			// 選択項目のIDラベル
 			$this->tmpl->addVar("_widget", "new_selected", 'checked');// ユーザIDが0のときは新規追加をチェック状態にする
 			
@@ -189,6 +243,7 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 			$this->tmpl->addVar("_widget", "id_label", $this->id);			// 選択項目のIDラベル
 			$this->tmpl->setAttribute('update_button', 'visibility', 'visible');// 更新ボタン表示
 		}
+		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
 		$this->tmpl->addVar("_widget", "id", $this->id);			// ID
 		$this->tmpl->addVar("add_id_field", "add_id", $addid);			// 追加ID
 		$this->tmpl->addVar("_widget", "name", $name);		// 名前
@@ -199,9 +254,6 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 			$visibleStr = 'checked';
 		}
 		$this->tmpl->addVar("_widget", "visible", $visibleStr);		// 表示状態
-
-		// 一覧を表示
-		$this->db->getAllPayMethodDef($this->langId, 0/*デフォルトのセットID*/, array($this, 'payDefLoop'));
 		
 		// インナーウィジェット選択メニューを作成
 		$this->sysDb->getAllIWidgetListByType($gEnvManager->getCurrentWidgetId(), self::IWIDGET_TYPE, array($this, 'iWidgetLoop'));
@@ -215,10 +267,9 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 		// パスの設定
 		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
 		$this->tmpl->addVar("_widget", "widget_sc_url", $gEnvManager->getCurrentWidgetScriptsUrl());
-		$this->tmpl->addVar("_widget", "image_path", $gEnvManager->getRootUrl() . '/resource/');		// 画像の格納場所
 	}
 	/**
-	 * 取得した配送方法定義をテンプレートに設定する
+	 * 取得した支払方法定義をテンプレートに設定する
 	 *
 	 * @param int $index			行番号(0～)
 	 * @param array $fetchedRow		フェッチ取得した行
@@ -244,18 +295,23 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 		}
 		$row = array(
 			'line_color' => $lineColor,											// 行のカラー
+			'serial' => $fetchedRow['po_serial'],								// シリアル番号
+			'index' => $index,													// 項目番号
 			'id'     => $this->convertToDispString($fetchedRow['po_id']),			// ID
 			'name'     => $this->convertToDispString($fetchedRow['po_name']),			// 表示名
-			'index'     => $this->convertToDispString($fetchedRow['po_index']),			// 表示順
+			'view_index'     => $this->convertToDispString($fetchedRow['po_index']),			// 表示順
 			'visible' => $visible,											// メニュー項目表示制御
 			'checked' => $checked														// 選択中かどうか
 		);
 		$this->tmpl->addVars('paymethod_list', $row);
 		$this->tmpl->parseTemplate('paymethod_list', 'a');
+		
+		// 表示中項目のシリアル番号を保存
+		$this->serialArray[] = $fetchedRow['po_serial'];
 		return true;
 	}
 	/**
-	 * 取得した配送方法インナーウィジェットをテンプレートに設定する
+	 * 取得した支払方法インナーウィジェットをテンプレートに設定する
 	 *
 	 * @param int $index			行番号(0～)
 	 * @param array $fetchedRow		フェッチ取得した行
