@@ -90,7 +90,7 @@ class ec_mainSendpwdWidgetContainer extends BaseWidgetContainer
 						if (empty($fromAddress)) $fromAddress = $gEnvManager->getSiteEmail();// 送信元が取得できないときは、システムのデフォルトメールアドレスを使用
 						$toAddress = $account;			// eメール(ログインアカウント)
 						//$forwardParam = M3_REQUEST_PARAM_FORWARD . '=' . urlencode('task=changepwd');		// パスワード変更画面へ遷移
-						$url = $gEnvManager->createCurrentPageUrl() . '&task=login&act=ec_login_by_mail&account=' . 
+						$url = $gEnvManager->createCurrentPageUrl() . '&task=login&act=ec_maillogin&account=' . 
 										urlencode($account) . '&pwd=' . urlencode($password);		// ログイン用URL
 						$mailParam = array();
 						$mailParam['PASSWORD'] = $password;
