@@ -323,6 +323,9 @@ class admin_ec_menuWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
 		$this->tmpl->addVar("_widget", "widget_sc_url", $gEnvManager->getCurrentWidgetScriptsUrl());
 		$this->tmpl->addVar("_widget", "image_path", $gEnvManager->getRootUrl() . '/resource/');		// 画像の格納場所
+		
+		// 共通スクリプトディレクトリを設定
+		$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
