@@ -79,7 +79,7 @@ class admin_imageWidgetContainer extends BaseWidgetContainer
 		$this->serial = 0;
 		$this->selConfigId = -1;			// 現在の設定中の定義ID
 		
-		$name		= '未設定';			// 定義名
+		$name		= '-- 未設定 --';			// 定義名
 		$imageUrl 	= '';							// 画像へのパス
 		$linkUrl	= '';			// リンク先
 		$align		= '';			// 表示位置
